/* (C) 2009 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate IP address details.
 *
 * $Id: AddrInfo.hh,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _ADDR_INFO_HH_
#define _ADDR_INFO_HH_

#include <sys/socket.h>
#include <string>

namespace HTTPTunnel {

class AddrInfo {
public:

	/*********/
	/* Types */
	/*********/

	// Address family
	enum Family { IPV4, IPV6, UNKNOWN_FAMILY };


	/***********/
	/* Methods */
	/***********/

	// Construction/destruction
	AddrInfo(std::string host);
	AddrInfo(const AddrInfo& that);
	~AddrInfo();

	// Assignment
	AddrInfo& operator=(const AddrInfo& that);

	// Accessors
	std::string getHostName(void) const;
	Family getFamily(void) const;
	int getInetFamily(void) const;
	size_t getAddrLen(void) const;
	const struct sockaddr* getAddr(void) const;
	std::string getAddrStr(void) const;

	// Mutators
	void setFamily(int family);
	void setAddr(size_t addrLen, const struct sockaddr* addr);
	void setAddrStr(std::string addrStr);


private:

	/********/
	/* Data */
	/********/

	// Hostname as a string
	std::string						m_host;

	// Address family
	Family							m_family;

	// Socket address
	size_t							m_addrLen;
	struct sockaddr				m_addr;

	// IP address as a string
	std::string						m_addrStr;

};


}	// namespace

#endif

