#include <string.h>
#include <strings.h>
#include "MD5.hh"
#include "MD4.hh"
#include "AuthDigest.hh"


namespace HTTPTunnel {


// Import MD4/MD5 functions
using namespace MD5Digest;
using namespace MD4Digest;


/********************/
/* Public Interface */
/********************/


// Calculate the response fields for digest authentication
std::string AuthDigest::MD5DigestResponse(std::string alg, std::string user,
	std::string passwd, std::string realm, std::string nonce, std::string cnonce,
	std::string cnoncec, std::string qop, std::string uri)
{
	// Construct digest HA1
	HASHHEX HA1;
	HASHHEX HA2 = "";
	HASHHEX HHResponse;

	DigestCalcHA1(alg.c_str(), user.c_str(), realm.c_str(), passwd.c_str(),
		nonce.c_str(), cnonce.c_str(), HA1);
	DigestCalcResponse(HA1, nonce.c_str(), cnoncec.c_str(), cnonce.c_str(),
		qop.c_str(), "GET", uri.c_str(), HA2, HHResponse);

	return HHResponse;
}


// Calculate raw MD4 digest
void AuthDigest::MD4Digest(const unsigned char* str, unsigned int len, unsigned char* md4)
{
	// Initialise
	MD4_CTX context;
	MD4Init(&context);
	MD4Update(&context, str, len);

	// Get digest
	HASH digest;
	MD4Final((unsigned char*)digest, &context);

	// Copy for caller
	memcpy(md4, digest, HASHLEN);
}

// Calculate string MD4 digest
std::string AuthDigest::MD4DigestStr(const unsigned char* str, unsigned int len)
{
	// Get digest
	HASH digest;
	MD4Digest(str, len, (unsigned char*)digest);

	// Convert to string and return
	HASHHEX HHResponse;
	CvtHex(digest, HHResponse);
	return HHResponse;
}


// Calculate raw MD5 digest
void AuthDigest::MD5Digest(const unsigned char* str, unsigned int len, unsigned char* md5)
{
	// Initialise
	MD5_CTX context;
	MD5Init(&context);
	MD5Update(&context, str, len);

	// Get digest
	HASH digest;
	MD5Final((unsigned char*)digest, &context);

	// Copy for caller
	memcpy(md5, digest, HASHLEN);
}

// Calculate string MD5 digest
std::string AuthDigest::MD5DigestStr(const unsigned char* str, unsigned int len)
{
	// Get digest
	HASH digest;
	MD5Digest(str, len, (unsigned char*)digest);

	// Convert to string and return
	HASHHEX HHResponse;
	CvtHex(digest, HHResponse);
	return HHResponse;
}


/*********************/
/* Private Interface */
/*********************/


// Hex conversion
void AuthDigest::CvtHex(HASH Bin, HASHHEX Hex)
{
	unsigned short i;
	unsigned char j;

	for (i = 0; i < HASHLEN; i++) {
		j = (Bin[i] >> 4) & 0xf;
		if (j <= 9)
			Hex[i*2] = (j + '0');
		 else
			Hex[i*2] = (j + 'a' - 10);
		j = Bin[i] & 0xf;
		if (j <= 9)
			Hex[i*2+1] = (j + '0');
		 else
			Hex[i*2+1] = (j + 'a' - 10);
	}
	Hex[HASHHEXLEN] = '\0';
}


// Calculate H(A1) as per spec
void AuthDigest::DigestCalcHA1(const char* pszAlg, const char* pszUserName,
	const char* pszRealm, const char* pszPassword, const char* pszNonce,
	const char* pszCNonce, HASHHEX SessionKey)
{
	MD5_CTX Md5Ctx;
	HASH HA1;

	MD5Init(&Md5Ctx);
	MD5Update(&Md5Ctx, (const unsigned char*)pszUserName, strlen(pszUserName));
	MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	MD5Update(&Md5Ctx, (const unsigned char*)pszRealm, strlen(pszRealm));
	MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	MD5Update(&Md5Ctx, (const unsigned char*)pszPassword, strlen(pszPassword));
	MD5Final((unsigned char*)HA1, &Md5Ctx);
	if (strcasecmp(pszAlg, "md5-sess") == 0) {
		MD5Init(&Md5Ctx);
		MD5Update(&Md5Ctx, (const unsigned char*)HA1, HASHLEN);
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
		MD5Update(&Md5Ctx, (const unsigned char*)pszNonce, strlen(pszNonce));
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
		MD5Update(&Md5Ctx, (const unsigned char*)pszCNonce, strlen(pszCNonce));
		MD5Final((unsigned char*)HA1, &Md5Ctx);
	}
	CvtHex(HA1, SessionKey);
}


// Calculate request-digest/response-digest as per HTTP Digest spec
void AuthDigest::DigestCalcResponse(HASHHEX HA1, const char* pszNonce,
	const char* pszNonceCount, const char* pszCNonce, const char* pszQop,
	const char* pszMethod, const char* pszDigestUri, HASHHEX HEntity,
	HASHHEX Response)
{
	MD5_CTX Md5Ctx;
	HASH HA2;
	HASH RespHash;
	HASHHEX HA2Hex;

	// calculate H(A2)
	MD5Init(&Md5Ctx);
	MD5Update(&Md5Ctx, (const unsigned char*)pszMethod, strlen(pszMethod));
	MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	MD5Update(&Md5Ctx, (const unsigned char*)pszDigestUri, strlen(pszDigestUri));
	if (strcasecmp(pszQop, "auth-int") == 0) {
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
		MD5Update(&Md5Ctx, (const unsigned char*)HEntity, HASHHEXLEN);
	}
	MD5Final((unsigned char*)HA2, &Md5Ctx);
	CvtHex(HA2, HA2Hex);

	// calculate response
	MD5Init(&Md5Ctx);
	MD5Update(&Md5Ctx, (const unsigned char*)HA1, HASHHEXLEN);
	MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	MD5Update(&Md5Ctx, (const unsigned char*)pszNonce, strlen(pszNonce));
	MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	if (*pszQop) {
		MD5Update(&Md5Ctx, (const unsigned char*)pszNonceCount, strlen(pszNonceCount));
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
		MD5Update(&Md5Ctx, (const unsigned char*)pszCNonce, strlen(pszCNonce));
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
		MD5Update(&Md5Ctx, (const unsigned char*)pszQop, strlen(pszQop));
		MD5Update(&Md5Ctx, (const unsigned char*)":", 1);
	}
	MD5Update(&Md5Ctx, (const unsigned char*)HA2Hex, HASHHEXLEN);
	MD5Final((unsigned char*)RespHash, &Md5Ctx);
	CvtHex(RespHash, Response);
}


} // namespace HTTPTunnel

