#ifndef _AUTH_DIGEST_HH_
#define _AUTH_DIGEST_HH_

#include <string>

namespace HTTPTunnel {

class AuthDigest {
public:

	/***********/
	/* Methods */
	/***********/

	// Calculate the response fields for digest authentication
	static std::string MD5DigestResponse(std::string alg, std::string user,
		std::string passwd, std::string realm, std::string nonce, std::string cnonce,
		std::string cnoncec, std::string qop, std::string uri);

	// Calculate MD4 digest
	static void MD4Digest(const unsigned char* str, unsigned int len, unsigned char* md4);
	static std::string MD4DigestStr(const unsigned char* str, unsigned int len);

	// Calculate MD5 digest
	static void MD5Digest(const unsigned char* str, unsigned int len, unsigned char* md5);
	static std::string MD5DigestStr(const unsigned char* str, unsigned int len);


private:

	/*************/
	/* Constants */
	/*************/

	// Hash lengths
	static const unsigned int			HASHLEN			= 16;
	static const unsigned int			HASHHEXLEN		= 32;


	/*********/
	/* Types */
	/*********/

	// Hashes
	typedef char HASH[HASHLEN];
	typedef char HASHHEX[HASHHEXLEN + 1];


	/***********/
	/* Methods */
	/***********/

	// Hex conversion
	static void CvtHex(HASH Bin, HASHHEX Hex);

	// Calculate H(A1) as per HTTP Digest spec
	static void DigestCalcHA1(const char* pszAlg, const char* pszUserName,
		const char* pszRealm, const char* pszPassword, const char* pszNonce,
		const char* pszCNonce, HASHHEX SessionKey);

	// Calculate request-digest/response-digest as per HTTP Digest spec
	static void DigestCalcResponse(HASHHEX HA1, const char* pszNonce,	
		const char* pszNonceCount, const char* pszCNonce, const char* pszQop,
		const char* pszMethod, const char* pszDigestUri, HASHHEX HEntity,
		HASHHEX Response);

};


}	// namespace HTTPTunnel

#endif

