/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Exception safe wrapper for pointers with more sane semantics.
 *
 * $Id: AutoPtr.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _AUTO_PTR_HH_
#define _AUTO_PTR_HH_

namespace HTTPTunnel {

template<class T>
class AutoPtr {
public:
	// Construction/destruction
	AutoPtr();
	AutoPtr(const AutoPtr<T>& that);
	AutoPtr(T* ptr);
	~AutoPtr();

	// Operators
	AutoPtr<T>& operator=(const AutoPtr<T>& that);
	void operator=(T* ptr);
	T& operator*(void) const;
	T* operator->(void) const;
	operator bool() const;

	// Accessors
	const T* get(void) const;
	T* getMutable(void) const;

	// Methods
	void freeOnDelete(bool fod);


private:
	// The wrapped pointer
	T*							m_ptr;

	// Free on delete?
	bool						m_freeOnDelete;

};


}	// namespace


// Include template methods
#include "AutoPtrT.cc"

#endif

