/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Template definitions for AutoPtr class.
 *
 * $Id: AutoPtrT.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


namespace HTTPTunnel {


// Construction/destruction
template<class T>
AutoPtr<T>::AutoPtr()
: m_ptr(0), m_freeOnDelete(true)
{
}

template<class T>
AutoPtr<T>::AutoPtr(const AutoPtr<T>& that)
: m_ptr(that.m_ptr), m_freeOnDelete(that.m_freeOnDelete)
{
	// Ensure AutoPtr we copy from doesn't free its pointer
	that.freeOnDelete(false);
}

template<class T>
AutoPtr<T>::AutoPtr(T* ptr)
: m_ptr(ptr), m_freeOnDelete(true)
{
}

template<class T>
AutoPtr<T>::~AutoPtr()
{
	// Do we have a pointer to free?
	if(m_freeOnDelete && m_ptr) {
		delete m_ptr;
		m_ptr = 0;
	}
}


/*************/
/* Operators */
/*************/


// Assignment
template<class T>
AutoPtr<T>& AutoPtr<T>::operator=(const AutoPtr<T>& that)
{
	// Self assignment
	if(this != &that) {
		// Do we have a pointer to free?
		if(m_freeOnDelete && m_ptr) {
			delete m_ptr;
			m_ptr = 0;
		}

		// Copy members
		m_ptr = that.m_ptr;
		m_freeOnDelete = that.m_freeOnDelete;

		// Ensure AutoPtr we copy from doesn't free its pointer
		that.freeOnDelete(false);
	}

	return *this;
}

template<class T>
void AutoPtr<T>::operator=(T* ptr)
{
	// If we already have a wrapped ptr, free it
	if(m_freeOnDelete && m_ptr)
		delete m_ptr;

	// Take new ptr
	m_ptr = ptr;
}

// Deref
template<class T>
T& AutoPtr<T>::operator*(void) const
{
	return *m_ptr;
}

// Composite deref
template<class T>
T* AutoPtr<T>::operator->(void) const
{
	return m_ptr;
}

// Conversion to bool
template<class T>
AutoPtr<T>::operator bool() const
{
	return (m_ptr != 0);
}


/*************/
/* Accessors */
/*************/


// Get raw pointer
template<class T>
const T* AutoPtr<T>::get(void) const
{
	return m_ptr;
}

template<class T>
T* AutoPtr<T>::getMutable(void) const
{
	return m_ptr;
}


// Set the free on delete flag
template<class T>
void AutoPtr<T>::freeOnDelete(bool fod)
{
	m_freeOnDelete = fod;
}


}	// namespace

