/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate function/method callbacks.
 *
 * $Id: CallbackT.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "Callback.hh"

namespace HTTPTunnel {


/******************************/
/******************************/
/* 1 argument global function */
/******************************/
/******************************/

// Construction/destruction
template<class A>
OneArgGlobalCallback<A>::OneArgGlobalCallback(OneArgGlobalCallbackFunc cb, A& arg1)
: Callback(), m_cb(cb), m_arg(arg1)
{
}

template<class A>
OneArgGlobalCallback<A>::OneArgGlobalCallback(const OneArgGlobalCallback<A>& that)
: Callback(that), m_cb(that.m_cb), m_arg(that.m_arg)
{
}

template<class A>
OneArgGlobalCallback<A>::~OneArgGlobalCallback()
{
}


// Assignment
template<class A>
OneArgGlobalCallback<A>& OneArgGlobalCallback<A>::operator=(
	const OneArgGlobalCallback<A>& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assignment
		Callback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
		m_arg = that.m_arg;
	}

	return *this;
}

// Copy ourselves
template<class A>
Callback* OneArgGlobalCallback<A>::clone(void)
{
	return (new OneArgGlobalCallback<A>(m_arg));
}

// Call the callback
template<class A>
void OneArgGlobalCallback<A>::operator()(void)
{
	(*m_cb)(m_arg);
}



/*******************************/
/*******************************/
/* 0 arg class method callback */
/*******************************/
/*******************************/

// Construction/Destruction
template<class T>
ZeroArgClassCallback<T>::ZeroArgClassCallback(ZeroArgClassCallbackMethod cb, T* obj)
: Callback(), m_cb(cb), m_obj(obj)
{
}

template<class T>
ZeroArgClassCallback<T>::ZeroArgClassCallback(const ZeroArgClassCallback<T>& that)
: Callback(that), m_cb(that.m_cb), m_obj(that.m_obj)
{
}

template<class T>
ZeroArgClassCallback<T>::~ZeroArgClassCallback()
{
}


// Assignment
template<class T>
ZeroArgClassCallback<T>& ZeroArgClassCallback<T>::operator=(
	const ZeroArgClassCallback& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assignment
		Callback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
		m_obj = that.m_obj;
	}

	return *this;
}

// Return a copy of ourselves
template<class T>
Callback* ZeroArgClassCallback<T>::clone(void)
{
	return (new ZeroArgClassCallback<T>(m_cb, m_obj));
}

// Call the callback
template<class T>
void ZeroArgClassCallback<T>::operator()(void)
{
	((*m_obj).*m_cb)();
}



/*******************************/
/*******************************/
/* 1 arg class method callback */
/*******************************/
/*******************************/

// Construction/Destruction
template<class T, class A>
OneArgClassCallback<T, A>::OneArgClassCallback(OneArgClassCallbackMethod cb, T* obj, A arg1)
: Callback(), m_cb(cb), m_obj(obj), m_arg1(arg1)
{
}

template<class T, class A>
OneArgClassCallback<T, A>::OneArgClassCallback(const OneArgClassCallback<T, A>& that)
: Callback(that), m_cb(that.m_cb), m_obj(that.m_obj), m_arg1(that.m_arg1)
{
}

template<class T, class A>
OneArgClassCallback<T, A>::~OneArgClassCallback()
{
}


// Assignment
template<class T, class A>
OneArgClassCallback<T, A>& OneArgClassCallback<T, A>::operator=(
	const OneArgClassCallback<T, A>& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assignment
		Callback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
		m_obj = that.m_obj;
		m_arg1 = that.m_arg1;
	}

	return *this;
}

// Return a copy of ourselves
template<class T, class A>
Callback* OneArgClassCallback<T, A>::clone(void)
{
	return (new OneArgClassCallback<T, A>(m_cb, m_obj, m_arg1));
}

// Call the callback
template<class T, class A>
void OneArgClassCallback<T, A>::operator()(void)
{
	((*m_obj).*m_cb)(m_arg1);
}



/*******************************/
/*******************************/
/* 2 arg class method callback */
/*******************************/
/*******************************/

// Construction/Destruction
template<class T, class A1, class A2>
TwoArgClassCallback<T, A1, A2>::TwoArgClassCallback(TwoArgClassCallbackMethod cb,
	T* obj, A1 arg1, A2 arg2)
: Callback(), m_cb(cb), m_obj(obj), m_arg1(arg1), m_arg2(arg2)
{
}

template<class T, class A1, class A2>
TwoArgClassCallback<T, A1, A2>::TwoArgClassCallback(
	const TwoArgClassCallback<T, A1, A2>& that)
: Callback(that), m_cb(that.m_cb), m_obj(that.m_obj), m_arg1(that.m_arg1),
  m_arg2(that.m_arg2)
{
}

template<class T, class A1, class A2>
TwoArgClassCallback<T, A1, A2>::~TwoArgClassCallback()
{
}


// Assignment
template<class T, class A1, class A2>
TwoArgClassCallback<T, A1, A2>& TwoArgClassCallback<T, A1, A2>::operator=(
	const TwoArgClassCallback<T, A1, A2>& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assignment
		Callback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
		m_obj = that.m_obj;
		m_arg1 = that.m_arg1;
		m_arg2 = that.m_arg2;
	}

	return *this;
}

// Return a copy of ourselves
template<class T, class A1, class A2>
Callback* TwoArgClassCallback<T, A1, A2>::clone(void)
{
	return (new TwoArgClassCallback<T, A1, A2>(m_cb, m_obj, m_arg1, m_arg2));
}

// Call the callback
template<class T, class A1, class A2>
void TwoArgClassCallback<T, A1, A2>::operator()(void)
{
	((*m_obj).*m_cb)(m_arg1, m_arg2);
}


}	// namespace

