/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Interface for authenticating a user at the client, and
 * tracking/controling resource usage.
 *
 * $Id: ClientAuthenticator.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CLIENT_AUTHENTICATOR_HH_
#define _CLIENT_AUTHENTICATOR_HH_

#include <string>
#include "Authenticator.hh"
#include "Exceptions.hh"
#include "User.hh"

namespace HTTPTunnel {

class Tunnel;

class ClientAuthenticator : public Authenticator {
public:
	// Construction/destruction
	ClientAuthenticator() throw(AuthError);
	virtual ~ClientAuthenticator();


	/*************/
	/* Accessors */
	/*************/

	// Get copy of current user details
	virtual User getUserDetails(std::string name);

	// Get whether user is authenticated for some tunnel
	virtual bool getUserAuthenticated(std::string name, Tunnel* tun);


	/************/
	/* Mutators */
	/************/

	// Set the username & passwd we use to authenticate at the server
	void setUserPasswd(std::string username, std::string passwd);


protected:

	/***********/
	/* Methods */
	/***********/

	// Create a new tunnel user
	virtual User createUser(std::string name, bool keepCached);


};


}	// namespace

#endif

