/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate client tunnel configuration settings in a handy blob.
 *
 * $Id: ClientConfigBlob.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CLIENT_CONFIG_BLOB_HH_
#define _CLIENT_CONFIG_BLOB_HH_

#include <string>
#include "ConfigBlob.hh"
#include "Enums.hh"

namespace HTTPTunnel {

class ClientConfigBlob : public ConfigBlob {
public:
	// Construction/destruction
	ClientConfigBlob(Enums::Protocol prot, bool ssl, std::string lhost,
		unsigned int lport, std::string shost, unsigned int sport);
	ClientConfigBlob(Enums::Protocol prot, bool ssl, std::string lhost,
		unsigned int lport, std::string shost, unsigned int sport,
		std::string dhost, unsigned int dport);
	ClientConfigBlob(const ClientConfigBlob& that);
	virtual ~ClientConfigBlob();

	// Assignment
	ClientConfigBlob& operator=(const ClientConfigBlob& that);

	// Accessors
	virtual std::string getType(void) const;
	virtual std::string getConfig(void) const;

	// Mutators
	void setClientAuth(std::string user, std::string passwd);
	void useProxy(std::string host, unsigned int port);
	void useProxy(std::string host, unsigned int port, std::string user, std::string passwd);


protected:

	/********/
	/* Data */
	/********/

	// SOCKS or direct?
	bool								m_socks;

	// TCP/UDP
	Enums::Protocol				m_prot;

	// SSL to server?
	bool								m_ssl;

	// Local listening address/port
	std::string						m_lhost;
	unsigned int					m_lport;

	// Server address port
	std::string						m_shost;
	unsigned int					m_sport;

	// Direct destination address/port
	std::string						m_dhost;
	unsigned int					m_dport;

	// Client authentication settings
	bool								m_cliAuth;
	std::string						m_cliUser;
	std::string						m_cliPasswd;

	// Proxy settings
	bool								m_viaProxy;
	std::string						m_phost;
	unsigned int					m_pport;
	bool								m_proxyAuth;
	std::string						m_proxyUser;
	std::string						m_proxyPasswd;

};


}	// namespace HTTPTunnel

#endif

