/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all global configuration for
 * a client tunneler.
 *
 * $Id: ClientSideConfig.hh,v 1.3 2008-07-11 11:22:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _GLOBAL_CLIENT_CONFIG_HH_
#define _GLOBAL_CLIENT_CONFIG_HH_

#include <string>
#include "Enums.hh"
#include "SideConfig.hh"

namespace HTTPTunnel {

class ProxySettings;
class Authenticator;
class ClientAuthenticator;

class ClientSideConfig : public SideConfig {
public:
	// Construction/destruction
	ClientSideConfig(Enums::Protocol prot, bool ssl, bool sockTun, std::string lhost,
		unsigned int lport, std::string shost, unsigned int sport, std::string suser,
		std::string spasswd, std::string dhost, unsigned int dport, std::string tune);
	ClientSideConfig(Enums::Protocol prot, bool ssl, bool sockTun, std::string lhost,
		unsigned int lport, std::string shost, unsigned int sport, std::string suser,
		std::string spasswd, std::string dhost, unsigned int dport, std::string tune,
		std::string phost, unsigned int pport, std::string puser, std::string ppasswd);
	ClientSideConfig(Enums::Protocol prot, bool ssl, std::string lhost, unsigned int lport,
		std::string shost, unsigned int sport, std::string suser, std::string spasswd,
		std::string tune);
	ClientSideConfig(Enums::Protocol prot, bool ssl, std::string lhost, unsigned int lport,
		std::string shost, unsigned int sport, std::string suser, std::string spasswd,
		std::string tune, std::string phost, unsigned int pport, std::string puser,
		std::string ppasswd);
	virtual ~ClientSideConfig();


	/*************/
	/* Accessors */
	/*************/

	// Client config?
	virtual bool isClient(void) const;

	// Are we going via a proxy?
	bool viaProxy(void) const;

	// What type of tunneler are we for?
	bool fixed(void) const;
	bool socks(void) const;

	// Get address/port for server end of tunnel
	std::string getServerIP(void) const;
	std::string getResolvedServerIP(void) const;
	unsigned int getServerPort(void) const;

	// Get address/port settings for fixed tunnel destination
	std::string getFixedDestIP(void) const;
	unsigned int getFixedDestPort(void) const;

	// Get address/port for next hop in tunnel
	std::string getNextHopIP(void) const;
	unsigned int getNextHopPort(void) const;

	// Proxy settings
	const ProxySettings* getProxySettings(void) const;

	// Tunnel tuning
	std::string getTunTune(void) const;


	/************/
	/* Mutators */
	/************/

	// Set client authorisation
	void setClientAuth(std::string user, std::string passwd);


	/*************/
	/* Utilities */
	/*************/

	// Serialize to a file
	virtual void serialize(std::ofstream& file);


protected:

	/***********/
	/* Methods */
	/***********/

	// Get domain for user
	std::string lookupUserDomain(std::string& user);


	/********/
	/* Data */
	/********/

	// IP address & port of server end
	std::string						m_serverIP;
	std::string						m_resolvedServerIP;
	unsigned int					m_serverPort;

	// IP address & port for fixed tunnel destination
	std::string						m_fixedDestIP;
	unsigned int					m_fixedDestPort;

	// Proxy/serverauth settings
	ProxySettings*					m_proxySettings;

	// Tunnel tuning
	std::string						m_tune;

};


}	// namespace

#endif
