/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to trigger a socket connection to some server.
 *
 * $Id: ConnectEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CONNECT_EVENT_HH_
#define _CONNECT_EVENT_HH_

#include "TimedEvent.hh"

namespace HTTPTunnel {

class Connection;
class ConnectProxy;

class ConnectEvent : public TimedEvent {
public:
	// Construction/destruction
	ConnectEvent(const Time& time, Connection* conn, ConnectProxy* proxy);
	virtual ~ConnectEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

	// Accessors
	unsigned int getConnectionID(void) const;
	std::string getHost(void) const;
	unsigned int getPort(void) const;


protected:

	/********/
	/* Data */
	/********/

	// Connection to connect out on
	Connection*							m_conn;

	// ConnectProxy handling this connection attempt
	ConnectProxy*						m_proxy;

};


}	// namespace

#endif

