/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Perform a blocking connect for a connection in a new thread.
 *
 * $Id: ConnectProxy.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CONNECT_PROXY_HH_
#define _CONNECT_PROXY_HH_

#include <string>
#include "EventReceiver.hh"
#include "Exceptions.hh"
#include "Mutex.hh"
#include "Time.hh"
#include "Enums.hh"

namespace HTTPTunnel {

class Connection;
class Sock;

class ConnectProxy : public EventReceiver {
public:
	// Construction/destruction
	ConnectProxy(Connection* conn, const Time& time, std::string host,
		unsigned int port, Enums::Protocol prot, bool ssl);
	virtual ~ConnectProxy();


	// Accessors
	std::string getHost(void) const;
	unsigned int getPort(void) const;

	// Utilites
	void scheduleConnect(const Time& time);


	/**********/
	/* Events */
	/**********/

	// Try to do the connect
	Sock* doConnect(void) throw(ConnectError);


private:

	/*************/
	/* Constants */
	/*************/

	// Time between asynchronous connect checks (milli-seconds)
	static const unsigned int			MIN_ASYNC_CHECK_PERIOD		= 20;
	static const unsigned int			MAX_ASYNC_CHECK_PERIOD		= 2000;


	/***********/
	/* Methods */
	/***********/

	// Initiate a connect
	Sock* initiateConnect(void) throw(ConnectError);

	// Check whether an asynchronous connect has completed
	Sock* checkAsyncConnect(void) throw(ConnectError);

	// Increase asynchronous connect period
	void scaleAsyncPeriod(bool reset);


	/********/
	/* Data */
	/********/

	// A Mutex
	Mutex									m_mtx;

	// The connection we proxy for
	Connection*							m_conn;

	// Address & port we are connecting to
	std::string							m_host;
	unsigned int						m_port;

	// Type of connection required
	Enums::Protocol					m_sockType;
	bool									m_sockSSL;

	// Asynchronous connection details
	bool									m_connecting;
	Sock*									m_asyncSock;
	unsigned int						m_asyncPeriod;

};


}	// namespace

#endif

