/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to record the result of a connect attempt.
 *
 * $Id: ConnectResultEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CONNECT_RESULT_EVENT_HH_
#define _CONNECT_RESULT_EVENT_HH_

#include <string>
#include "Event.hh"
#include "Enums.hh"

namespace HTTPTunnel {

class Tunneler;

class ConnectResultEvent : public Event {
public:

	/*********/
	/* Types */
	/*********/

	// Connect result types
	enum ConnectResultType { GENERAL_ERROR = 0, FIREWALLED, ASYNC, SUCCESS };


	/***********/
	/* Methods */
	/***********/

	// Construction/destruction
	ConnectResultEvent(Tunneler* tunneler, unsigned int connID, std::string host,
		unsigned int port, Enums::Protocol prot, bool ssl, ConnectResultType type);
	virtual ~ConnectResultEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

	// Accessors
	unsigned int getConnectionID(void) const;
	std::string getHost(void) const;
	unsigned int getPort(void) const;
	Enums::Protocol getProtocol(void) const;
	bool getSSL(void) const;
	ConnectResultType getType(void) const;
	static std::string getTypeStr(ConnectResultType type);


protected:

	/********/
	/* Data */
	/********/

	// Reference to controlling tunneler
	Tunneler*								m_tunneler;

	// ID of connection error is from
	unsigned int							m_connID;

	// Host/port/protocol connect was to
	std::string								m_host;
	unsigned int							m_port;
	Enums::Protocol						m_protocol;
	bool										m_ssl;

	// Connection result type
	ConnectResultType						m_type;

};


}	// namespace

#endif

