/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to record a fatal error on some connection.
 *
 * $Id: ConnectionErrorEvent.cc,v 1.2 2009-04-24 15:37:33 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <algorithm>
#include "ConnectionErrorEvent.hh"
#include "Debug.hh"
#include "Tunneler.hh"
#include "MutexVar.hh"

namespace HTTPTunnel {


// Construction/destruction
ConnectionErrorEvent::ConnectionErrorEvent(unsigned int connID,
	Tunnel::TunnelErrorType type, Tunneler* tunneler)
: Event(), IdentifyEvent<unsigned int>(connID), m_mtx(), m_connID(connID),
  m_errors(), m_tunneler(tunneler)
{
	// Add initial error to list
	m_errors.push_back(type);
}

ConnectionErrorEvent::~ConnectionErrorEvent()
{
}


// Display event details for debugging
void ConnectionErrorEvent::details(std::stringstream& dbg)
{
	dbg << "ConnectionErrorEvent: ";
	Event::details(dbg);
}


// Report the error
void ConnectionErrorEvent::execute(void)
{
	DPRINTV("ConnectionErrorEvent::execute()");

	MutexVar mv(m_mtx);

	// Let connections controlling tunneler know
	m_tunneler->connectionErrors(m_connID, m_errors);
}


// Add new error to list
void ConnectionErrorEvent::addError(Tunnel::TunnelErrorType type)
{
	MutexVar mv(m_mtx);

	// Filter out duplicates
	std::vector<Tunnel::TunnelErrorType>::iterator eit;
	eit = std::find(m_errors.begin(), m_errors.end(), type);
	if(eit == m_errors.end())
		m_errors.push_back(type);
}


}	// namespace

