/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Manage all blocking Connection operations without requiring a
 * thread per Connection object.
 *
 * $Id: ConnectionManager.hh,v 1.3 2009-02-27 11:56:19 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _CONNECTION_MANAGER_HH_
#define _CONNECTION_MANAGER_HH_

#include <string>
#include <map>
#include "EventReceiver.hh"
#include "Mutex.hh"
#include "Enums.hh"

namespace HTTPTunnel {

class Connection;
class ConnectProxy;
class Time;

class ConnectionManager : public EventReceiver {
public:
	// Construction/destruction
	ConnectionManager();
	virtual ~ConnectionManager();


	/*************/
	/* Utilities */
	/*************/

	// Connection management
	void addConnection(Connection* conn);
	void delConnection(Connection* conn);

	// Proxy connection management
	void addProxyConnect(Connection* conn, const Time& time, std::string host,
		unsigned int port, Enums::Protocol prot, bool ssl);
	void delProxyConnect(Connection* conn);

	// Display some audit stats
	void audit(void);


	/**********/
	/* Events */
	/**********/

	// Try reading from our managed connections
	void readConnections(void);


private:

	/*************/
	/* Constants */
	/*************/

	// Time (in milliseconds) between polls
	static const unsigned int		POLL_PERIOD				= 5;


	/***********/
	/* Methods */
	/***********/

	// Connection polling thread
	void pollThread(void);


	/********/
	/* Data */
	/********/

	// A mutex
	Mutex												m_mtx;

	// The managed connections
	std::map<unsigned int, Connection*>		m_connections;

	// Active connect proxies
	std::map<unsigned int, ConnectProxy*>	m_connectProxies;

	// Polling thread
	ThreadManager									m_threadMgr;
	Thread*											m_pollThread;
	bool												m_shutDown;

};


}	// namespace

#endif

