/* (C) Phil Karn, Jim Gillogly, Nikos Mavroyanopoulos, Richard Mills.
 *
 * DES encryption/decryption functions.
 *
 * $Id: DES.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _DES_HH_
#define _DES_HH_

#include <inttypes.h>

namespace HTTPTunnel {

class DES {
public:

	/*********/
	/* Types */
	/*********/

	// Fixed size types
	typedef uint32_t word32;
	typedef uint16_t word16;

	// DES key structure
	typedef struct des_key {
		char kn[16][8];
		word32 sp[8][64];
		char iperm[16][16][8];
		char fperm[16][16][8];
	} DES_KEY;


	/***********/
	/* Methods */
	/***********/

	// Set key (initialize key schedule array)
	static int set_key(DES_KEY * dkey, char *user_key, int len);

	// In-place encryption/decryption of 64-bit block
	static void encrypt(DES_KEY * key, char *block, bool bigendian);
	static void decrypt(DES_KEY * key, char *block, bool bigendian);


private:

	/***********/
	/* Methods */
	/***********/

	// DES helper methods
	static int desinit(DES_KEY* key);
	static void permute_ip(char *inblock, DES_KEY * key, char *outblock);
	static void permute_fp(char *inblock, DES_KEY * key, char *outblock);
	static word32 f(DES_KEY * key, word32 r, char *subkey);
	static void perminit_ip(DES_KEY * key);
	static void perminit_fp(DES_KEY * key);
	static void spinit(DES_KEY * key);
	static word32 rotl32(word32 x, word32 n);
	static word32 rotr32(word32 x, word32 n);
	static word32 byteswap32(word32 x);


	/********/
	/* Data */
	/********/

	// DES tables
	static char						ip[64];
	static char						fp[64];
	static char						pc1[56];
	static char						totrot[16];
	static char						pc2[48];
	static char						si[8][64];
	static char						p32i[32];
	static int						bytebit[8];
	static int						nibblebit[4];

};


}	// namespace

#endif

