/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Default user authentication at server; always authenticates.
 *
 * $Id: DefaultServerAuthenticator.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "DefaultServerAuthenticator.hh"
#include "Logger.hh"
#include "Debug.hh"
#include "User.hh"
#include "MutexVar.hh"
#include "ServerAuthSettings.hh"


namespace HTTPTunnel {


// Reference to the logger
extern Logger* g_pLogger;


// Construction/destruction
DefaultServerAuthenticator::DefaultServerAuthenticator() throw(AuthError)
: ServerAuthenticator()
{
	DPRINTV("DefaultServerAuthenticator::DefaultServerAuthenticator()");

	// Create initial user
	std::string initialUser = m_defaultAuthSettings->getUser();
	m_users[initialUser] = createUser(initialUser, true);
}

DefaultServerAuthenticator::~DefaultServerAuthenticator()
{
	DPRINTV("DefaultServerAuthenticator::~DefaultServerAuthenticator()");
}


/********************/
/* Public Interface */
/********************/


/*************/
/* Accessors */
/*************/


// Get copy of current user details
User DefaultServerAuthenticator::getUserDetails(std::string name)
{
	MutexVar mv(m_mtx);

	// Lookup user in cached details
	User* user = getUser(name);
	if(user) {
		return *user;
	}

	// Return blank authenticated user details
	User blankUser;
	return blankUser;
}


/*************/
/* Utilities */
/*************/


// Authenticate a new user
void DefaultServerAuthenticator::authenticate(std::string userName, Tunnel* tun,
	const std::vector<std::string>& authArgs)
{
	DPRINTV("DefaultServerAuthenticator::authenticate()");

	MutexVar mv(m_mtx);

	// Let base class cache this user name
	ServerAuthenticator::authenticate(userName, tun, authArgs);

	// Authenticate user and let them know about their new tunnel
	User* user = getUser(userName);
	user->setAuthenticated(true, tun);
	user->addTunnel(tun, true);
}


}	// namespace

