/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Handle dummy reading/writing for one end of a raw tunnel
 * connection.
 *
 * $Id: DummyRawConnection.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "DummyRawConnection.hh"
#include "Debug.hh"


namespace HTTPTunnel {


// Construction/destruction
DummyRawConnection::DummyRawConnection(Tunneler* tunneler, const TunnelID& tid)
: RawConnection(tunneler, tid)
{
	#ifdef DEBUG_TUN
	std::stringstream dbg;
	dbg << "DummyRawConnection::DummyRawConnection() - connection " << getID();
	DPRINTV(dbg.str());
	#endif

	// Construct reader/writer and become connected
	createReaderWriter();
}

DummyRawConnection::~DummyRawConnection()
{
	#ifdef DEBUG_TUN
	std::stringstream dbg;
	dbg << "DummyRawConnection::~DummyRawConnection() - connection " << getID();
	DPRINTV(dbg.str());
	#endif
}


/*************/
/* Utilities */
/*************/


// Dummy reading
void DummyRawConnection::read(void) throw(CommsError)
{
	// Do nothing
}

// Dummy writing
void DummyRawConnection::write(MsgParms* parms) throw(CommsError)
{
	// Do nothing
}


}	// namespace


