/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to be passed between threads.
 *
 * $Id: Event.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _EVENT_HH_
#define _EVENT_HH_

#include <sstream>
#include "Time.hh"

namespace HTTPTunnel {

class Event {
public:

	/**************/
	/* Predicates */
	/**************/

	// Compare events based on their scheduled run times
	struct PredRunTime {
		bool operator()(const Event* e1, const Event* e2) {
			return (e1->getRunTime() < e2->getRunTime());
		}
	};


	/***********/
	/* Methods */
	/***********/

	// Construction/destruction
	Event();
	Event(const Time& time);
	Event(const Event& that);
	virtual ~Event();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void) = 0;

	// Accessors
	const Time& getRunTime(void) const;

	// Mutators
	void setRunTime(const Time& time);


protected:

	/********/
	/* Data */
	/********/

	// Time this event is scheduled for
	Time							m_runTime;

};


}	// namespace

#endif

