/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Apply firewalling rules for the tunnel server.
 *
 * $Id: Firewall.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _FIREWALL_HH_
#define _FIREWALL_HH_

#include <string>
#include <list>
#include <fstream>
#include "Mutex.hh"

namespace HTTPTunnel {

class Firewall {
public:
	// Construction/destruction
	Firewall(std::string ips, std::string ports);
	~Firewall();

	// Is a requested tunnel destination allowed?
	bool isAllowed(std::string dest);
	bool isAllowed(std::string ip, unsigned int port);

	// Set firewall rules
	void denyIPs(std::string dest);
	void denyPorts(std::string dest);

	// Serialize to a file
	void serialize(std::ofstream& file);


private:

	/***********/
	/* Methods */
	/***********/

	// Is an IP address or port banned
	bool ipBanned(std::string ip);
	bool portBanned(unsigned int port);

	// Resolve an address to a string IP address
	std::string resolve(std::string address);


	/********/
	/* Data */
	/********/

	// Mutex
	Mutex								m_mtx;

	// List of denied IP addresses and ports
	std::list<std::string>		m_denyIPs;
	std::vector<std::string>	m_denyWildcardIPs;
	std::list<unsigned int>		m_denyPorts;

};


}	// namespace

#endif

