/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * An event to flush a connections data buffer.
 *
 * $Id: FlushConnectionEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _FLUSH_CONNECTION_EVENT_HH_
#define _FLUSH_CONNECTION_EVENT_HH_

#include "TimedEvent.hh"
#include "IdentifyEvent.hh"

namespace HTTPTunnel {

class Tunneler;

class FlushConnectionEvent : public TimedEvent, public IdentifyEvent<unsigned int> {
public:
	// Construction/destruction
	FlushConnectionEvent(const Time& time, unsigned int connID, bool retry,
		Tunneler* tunneler);
	virtual ~FlushConnectionEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);


protected:

	/********/
	/* Data */
	/********/

	// Tunneler this event is for
	Tunneler*							m_tunneler;

	// Connection details
	unsigned int						m_connID;
	bool									m_retry;

};


}	// namespace

#endif

