/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate global configuration settings in a handy blob.
 *
 * $Id: GlobalConfigBlob.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "GlobalConfigBlob.hh"
#include "Debug.hh"


namespace HTTPTunnel {


// Construction/destruction
GlobalConfigBlob::GlobalConfigBlob()
: ConfigBlob(), m_debug(ERROR)
{
}

GlobalConfigBlob::GlobalConfigBlob(unsigned int debug)
: ConfigBlob(), m_debug(debug)
{
	if(m_debug > VERBOSE)
		m_debug = VERBOSE;
}

GlobalConfigBlob::GlobalConfigBlob(const GlobalConfigBlob& that)
: ConfigBlob(that), m_debug(that.m_debug)
{
}

GlobalConfigBlob::~GlobalConfigBlob()
{
}


// Assignment
GlobalConfigBlob& GlobalConfigBlob::operator=(const GlobalConfigBlob& that)
{
	if(this != &that) {
		// Base class
		ConfigBlob::operator=(that);

		// Our members
		m_debug = that.m_debug;
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get blob type
std::string GlobalConfigBlob::getType(void) const
{
	return "GLOBAL";
}

// Get blob config as a parsable stream
std::string GlobalConfigBlob::getConfig(void) const
{
	std::stringstream cfg;

	// Format ourselves
	cfg << "debug " << m_debug << std::endl;
	cfg << "nodaemon" << std::endl;

	return cfg.str();
}


/************/
/* Mutators */
/************/


// Set debug level
void GlobalConfigBlob::setDebug(unsigned int debug)
{
	m_debug = debug;
}


}	// namespace HTTPTunnel

