/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Handle reading/writing for one end of an HTTP tunnel
 * connection.
 *
 * $Id: HTTPConnection.hh,v 1.2 2008-07-11 11:22:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_CONNECTION_HH_
#define _HTTP_CONNECTION_HH_

#include "Connection.hh"

namespace HTTPTunnel {

class Tunneler;

class HTTPConnection : public Connection {
public:
	// Construction/destruction
	HTTPConnection(Sock* sock, Tunneler* tunneler);
	HTTPConnection(Tunneler* tunneler);
	virtual ~HTTPConnection();


	/***********/
	/* Methods */
	/***********/

	// Let us know the result of a connection attempt
	virtual void connectResult(ConnectResultEvent::ConnectResultType result,
		Sock* sock) throw(CommsError);

	// Poll the other end of this connection with an empty GET message
	void poll(void) throw(CommsError);

	// Accessors
	std::string getClientAddr(void) const;
	unsigned int getNoMsgsRecvd(void) const;
	bool getPersistent(void) const;

	// Mutators
	void msgRecvd(void);
	void setPersistent(void);


protected:

	/***********/
	/* Methods */
	/***********/

	// Construct reader/writer
	virtual void createReaderWriter(void);


	/********/
	/* Data */
	/********/

	// Address of connecting client
	std::string						m_clientAddr;

	// Count of number of HTTP msgs received over us
	unsigned int					m_noMsgsRecvd;

	// Are we a persistent connection?
	bool								m_persistent;

};


}	// namespace

#endif

