/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an HTTP GET request message.
 *
 * $Id: HTTPGetMsg.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_GET_MSG_HH_
#define _HTTP_GET_MSG_HH_

#include <string>
#include "Exceptions.hh"
#include "HTTPRequestMsg.hh"

namespace HTTPTunnel {

class HTTPMsgParms;
class ClientSideConfig;

class HTTPGetMsg : public HTTPRequestMsg {
public:
	// Construction/destruction
	HTTPGetMsg();
	HTTPGetMsg(const HTTPMsgParms* parms, std::string uri, const ClientSideConfig* cfg);
	HTTPGetMsg(const HTTPGetMsg& that);
	virtual ~HTTPGetMsg();

	// Construction from a raw read data stream
	HTTPGetMsg(RawBuff& readdata) throw(HTTPMsgParsingError);

	// Assignment
	HTTPGetMsg& operator=(const HTTPGetMsg& that);


protected:

	/*************/
	/* Constants */
	/*************/

	// Maximum UUEncoded characters per line
	static const unsigned int				MAX_UU_CHARS_LINE		= 256;


	/***********/
	/* Methods */
	/***********/

	// Parse and extract any UUEncoded message content
	virtual void extractContent(RawBuff& readdata) throw(ParsingError);

	// Attempt to parse headers from a raw byte-stream
	virtual void parseHdrs(RawBuff& data, bool& eoh, std::string& hdrline)
		throw(HTTPMsgParsingError);

	// Pack/unpack payload data to/from a header string
	void packPayload(const RawBuff& payload, std::stringstream& str);
	void unpackPayload(std::string& header);


	/********/
	/* Data */
	/********/

	// UUEncoded data
	std::string								m_uuData;

	// Reported length of UUEncoded data
	unsigned int							m_repUULen;

	// URI encoded header fields
	std::string								m_uriEncFields;

private:

};


}	// namespace HTTPTunnel

#endif

