/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an HTTP message.
 *
 * $Id: HTTPMsg.hh,v 1.3 2008-08-07 20:30:20 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_MSG_HH_
#define _HTTP_MSG_HH_

#include <string>
#include <vector>
#include <map>
#include "Exceptions.hh"
#include "HTTPMsgParms.hh"

namespace HTTPTunnel {

class Payload;
class RawBuff;

class HTTPMsg {
public:
   // Basic Construction/destruction
	HTTPMsg();
   HTTPMsg(const HTTPMsgParms* parms);
   HTTPMsg(const HTTPMsg& that);
   virtual ~HTTPMsg();

	// Assignment
	HTTPMsg& operator=(const HTTPMsg& that);


	/***********/
	/* Methods */
	/***********/

	// Write ourselves out as a stream of bytes
	virtual void output(RawBuff& dest);

	// Get message parameters
	const HTTPMsgParms* getParms(void) const;
	HTTPMsgParms* getParmsMutable(void);
	const std::map<std::string, std::vector<std::string> >& getAuthArgs(void) const;

	// Minimum headers passed as expected?
	bool allReqHeaders(void) const;
	bool allRespHeaders(void) const;


protected:

	/***********/
	/* Methods */
	/***********/

	// Parse and extract any message content
	virtual void extractContent(RawBuff& readdata) throw(ParsingError) = 0;

	// Get start line string
	virtual std::string getStartLine(void) const = 0;

	// Attempt to parse headers from a raw byte-stream
	virtual void parseHdrs(RawBuff& data, bool& eoh, std::string& hdrline)
		throw(HTTPMsgParsingError);

	// Find the next newline in some raw data
	bool findNewLine(RawBuff& buff, const unsigned char*& start,
		const unsigned char*& end) const;
	bool findNewLine(RawBuff& buff, const unsigned char*& start,
		const unsigned char*& end, bool& split) const;

	// Construct the longest string we can from some raw data
	std::string makeString(const unsigned char* start, const unsigned char* end) const;

	// Get header string
	std::string getHeader(void) const;


	/********/
	/* Data */
	/********/

	// Message parameters
	HTTPMsgParms*							m_parms;

	// The header fields
	std::string								m_generalHeader;
	std::string								m_reqRespHeader;
	std::string								m_entityHeader;
	std::string								m_ourHeader;

	// Current line we're parsing
	unsigned int							m_parsingLine;

	// Flags to indicate if we've seen particular headers
	bool										m_seenTID;
	bool										m_seenSeqNo;
	bool										m_seenConn;
	bool										m_seenDest;
	bool										m_seenUUData;
	bool										m_seenUULen;
	bool										m_seenAck;
	bool										m_seenQuotas;
	bool										m_seenCliVer;
	bool										m_seenSplit;
	bool										m_seenTest;
	bool										m_seenTune;
	bool										m_seenNotif;

	// Authentication arguments
	std::map<std::string,
		std::vector<std::string> >		m_authArgs;

	// Split header parameters
	std::string								m_lastTunId;
	bool										m_lastTunIdSplit;


private:

};


}	// namespace HTTPTunnel

#endif

