/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate parameters for an HTTP message.
 *
 * $Id: HTTPMsgParms.cc,v 1.3 2008-08-07 20:30:20 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <iostream>
#include "HTTPMsgParms.hh"
#include "Payload.hh"
#include "ProxySettings.hh"
#include "ServerAuthSettings.hh"


namespace HTTPTunnel {


// Construction/destruction
HTTPMsgParms::HTTPMsgParms()
: MsgParms(), m_state(Tunnel::UNKNOWNSTATE), m_testState(Tunnel::NO_TESTING),
  m_ver("1.1"), m_ack(""), m_tunDest(""), m_useHeaderFields(true), m_proxyCfg(0),
  m_serverAuthCfg(0), m_user(), m_quotas(), m_respCode(200), m_respPhrase("OK"),
  m_uri(""), m_cliVer(""), m_tune(""), m_tunnel(0), m_connClose(false),
  m_connKeepAlive(false), m_proxyConnClose(false), m_proxyConnKeepAlive(false),
  m_notifs()
{
}

HTTPMsgParms::HTTPMsgParms(Tunnel* tunnel, Payload* payload, bool retry, User& user,
	Tunnel::TunnelState state, std::string ver, std::string ack, std::string tunDest,
	bool useHeader)
: MsgParms(tunnel->getTidStr(), payload, retry), m_state(state),
  m_testState(tunnel->getTestState()), m_ver(ver), m_ack(ack), m_tunDest(tunDest),
  m_useHeaderFields(useHeader), m_proxyCfg(tunnel->getProxySettings()),
  m_serverAuthCfg(tunnel->getServerAuthSettings()), m_user(user), m_quotas(user.getQuotas()),
  m_respCode(200), m_respPhrase("OK"), m_uri(""), m_cliVer(""), m_tune(""),
  m_tunnel(tunnel), m_connClose(false), m_connKeepAlive(false), m_proxyConnClose(false),
  m_proxyConnKeepAlive(false), m_notifs(tunnel->getSendNotifMsgs())
{
}

HTTPMsgParms::HTTPMsgParms(const HTTPMsgParms& that)
: MsgParms(that), m_state(that.m_state), m_testState(that.m_testState),
  m_ver(that.m_ver), m_ack(that.m_ack), m_tunDest(that.m_tunDest),
  m_useHeaderFields(that.m_useHeaderFields), m_proxyCfg(that.m_proxyCfg),
  m_serverAuthCfg(that.m_serverAuthCfg), m_user(that.m_user), m_quotas(that.m_quotas),
  m_respCode(that.m_respCode), m_respPhrase(that.m_respPhrase), m_uri(that.m_uri),
  m_cliVer(that.m_cliVer), m_tune(that.m_tune), m_tunnel(that.m_tunnel),
  m_connClose(that.m_connClose), m_connKeepAlive(that.m_connKeepAlive),
  m_proxyConnClose(that.m_proxyConnClose), m_proxyConnKeepAlive(that.m_proxyConnKeepAlive),
  m_notifs(that.m_notifs)
{
}

HTTPMsgParms::~HTTPMsgParms()
{
}


// Assignment
HTTPMsgParms& HTTPMsgParms::operator=(const HTTPMsgParms& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class
		MsgParms::operator=(that);

		// Our members
		m_state = that.m_state;
		m_testState = that.m_testState;
		m_ver = that.m_ver;
		m_ack = that.m_ack;
		m_tunDest = that.m_tunDest;
		m_useHeaderFields = that.m_useHeaderFields;
		m_proxyCfg = that.m_proxyCfg;
		m_serverAuthCfg = that.m_serverAuthCfg;
		m_user = that.m_user;
		m_quotas = that.m_quotas;
		m_respCode = that.m_respCode;
		m_respPhrase = that.m_respPhrase;
		m_uri = that.m_uri;
		m_cliVer = that.m_cliVer;
		m_tune = that.m_tune;
		m_tunnel = that.m_tunnel;
		m_connClose = that.m_connClose;
		m_connKeepAlive = that.m_connKeepAlive;
		m_proxyConnClose = that.m_proxyConnClose;
		m_proxyConnKeepAlive = that.m_proxyConnKeepAlive;
		m_notifs = that.m_notifs;
	}

	return *this;
}

// Clone
MsgParms* HTTPMsgParms::clone(void) const
{
	return new HTTPMsgParms(*this);
}


/*************/
/* Accessors */
/*************/


// Get HTTP connection state
Tunnel::TunnelState HTTPMsgParms::getState(void) const
{
	return m_state;
}

// Get tunnel testing state
Tunnel::TunnelTestState HTTPMsgParms::getTestState(void) const
{
	return m_testState;
}

// Get HTTP version
std::string HTTPMsgParms::getVer(void) const
{
	return m_ver;
}

// Get ack
std::string HTTPMsgParms::getAck(void) const
{
	return m_ack;
}

// Get tunnel destination address
std::string HTTPMsgParms::getTunDest(void) const
{
	return m_tunDest;
}

// Get whether we are using header fields for tunneling
bool HTTPMsgParms::getUseHeaderFields(void) const
{
	return m_useHeaderFields;
}

// Get tunnels proxy config
ProxySettings* HTTPMsgParms::getProxySettings(void)
{
	return m_proxyCfg;
}

// Get tunnels serverauth config
ServerAuthSettings* HTTPMsgParms::getServerAuthSettings(void)
{
	return m_serverAuthCfg;
}

// Get user msg is for
const User& HTTPMsgParms::getUser(void) const
{
	return m_user;
}

// Get quotas for user
const Quotas& HTTPMsgParms::getQuotas(void) const
{
	return m_quotas;
}

// Get response code
unsigned short HTTPMsgParms::getRespCode(void) const
{
	return m_respCode;
}

// Get response phrase
std::string HTTPMsgParms::getRespPhrase(void) const
{
	return m_respPhrase;
}

// Get URI
std::string HTTPMsgParms::getURI(void) const
{
	return m_uri;
}

// Get client version identifier
std::string HTTPMsgParms::getCliVer(void) const
{
	return m_cliVer;
}

// Get tunnel tuning settings
std::string HTTPMsgParms::getTunTune(void) const
{
	return m_tune;
}

// Get whether user is authenticated for this msgs tunnel
bool HTTPMsgParms::getUserAuthenticated(void) const
{
	return m_user.getAuthenticated(m_tunnel);
}

// Get whether we saw a Connection close option
bool HTTPMsgParms::getConnClose(void) const
{
	return m_connClose;
}

// Get whether we saw a Connection keep-alive option
bool HTTPMsgParms::getConnKeepAlive(void) const
{
	return m_connKeepAlive;
}

// Get whether we saw a Proxy-Connection close option
bool HTTPMsgParms::getProxyConnClose(void) const
{
	return m_proxyConnClose;
}

// Get whether we saw a Proxy-Connection keep-alive option
bool HTTPMsgParms::getProxyConnKeepAlive(void) const
{
	return m_proxyConnKeepAlive;
}

// Get notification msgs
std::vector<std::string> HTTPMsgParms::getNotifs(void) const
{
	return m_notifs;
}


/************/
/* Mutators */
/************/


// Set HTTP connection state
void HTTPMsgParms::setState(Tunnel::TunnelState state)
{
	m_state = state;
}

// Set tunnel testing state
void HTTPMsgParms::setTestState(Tunnel::TunnelTestState testState)
{
	m_testState = testState;
}

// Set HTTP version
void HTTPMsgParms::setVer(std::string ver)
{
	m_ver = ver;
}

// Set ack
void HTTPMsgParms::setAck(std::string ack)
{
	m_ack = ack;
}

// Set tunnel destination address
void HTTPMsgParms::setTunDest(std::string dest)
{
	m_tunDest = dest;
}

// Set whether we are using header fields for tunneling
void HTTPMsgParms::setUseHeaderFields(bool uh)
{
	m_useHeaderFields = uh;
}

// Set response code & phrase
void HTTPMsgParms::setRespCodePhrase(unsigned short code, std::string phrase)
{
	m_respCode = code;
	m_respPhrase = phrase;
}

// Set URI
void HTTPMsgParms::setURI(std::string uri)
{
	m_uri = uri;
}

// Set proxy settings
void HTTPMsgParms::setProxySettings(ProxySettings* settings)
{
	m_proxyCfg = settings;
}

// Set server auth settings
void HTTPMsgParms::setServerAuthSettings(ServerAuthSettings* settings)
{
	m_serverAuthCfg = settings;
}

// Set user
void HTTPMsgParms::setUser(const User& user)
{
	m_user = user;
}

// Set users quotas
void HTTPMsgParms::setQuotas(const Quotas& quotas)
{
	m_quotas = quotas;
}

// Set client version identifier
void HTTPMsgParms::setCliVer(std::string cliVer)
{
	m_cliVer = cliVer;
}

// Set tunnel tunable settings
void HTTPMsgParms::setTunTune(std::string tune)
{
	m_tune = tune;
}

// Set Connection option seen
void HTTPMsgParms::setConnOption(std::string opt)
{
	if(opt == "close" || opt == "Close") {
		m_connClose = true;
	}
	else if(opt == "keep-alive" || opt == "Keep-Alive") {
		m_connKeepAlive = true;
	}
}

// Set Proxy-Connection option seen
void HTTPMsgParms::setProxyConnOption(std::string opt)
{
	if(opt == "close" || opt == "Close") {
		m_proxyConnClose = true;
	}
	else if(opt == "keep-alive" || opt == "Keep-Alive") {
		m_proxyConnKeepAlive = true;
	}
}

// Set notification msgs
void HTTPMsgParms::setNotifs(std::vector<std::string>& msgs)
{
	m_notifs = msgs;
}

// Add a notification msg
void HTTPMsgParms::addNotif(std::string msg)
{
	m_notifs.push_back(msg);
}


}	// namespace

