/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an HTTP POST request message.
 *
 * $Id: HTTPPostMsg.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_POST_MSG_HH_
#define _HTTP_POST_MSG_HH_

#include <string>
#include "Exceptions.hh"
#include "HTTPRequestMsg.hh"

namespace HTTPTunnel {

class HTTPMsgParms;
class ClientSideConfig;

class HTTPPostMsg : public HTTPRequestMsg {
public:
	// Construction/destruction
	HTTPPostMsg();
	HTTPPostMsg(const HTTPMsgParms* parms, std::string uri, const ClientSideConfig* cfg);
	HTTPPostMsg(const HTTPPostMsg& that);
	virtual ~HTTPPostMsg();

	// Construction from raw read data stream
	HTTPPostMsg(RawBuff& readdata) throw(HTTPMsgParsingError);

	// Assignment
	HTTPPostMsg& operator=(const HTTPPostMsg& that);


	/***********/
	/* Methods */
	/***********/

	// Write ourselves out as a stream of bytes
	virtual void output(RawBuff& dest);


protected:

	/***********/
	/* Methods */
	/***********/

	// Parse and extract any message content
	virtual void extractContent(RawBuff& readdata) throw(ParsingError);

	// Attempt to parse headers from a raw byte-stream
	virtual void parseHdrs(RawBuff& data, bool& eoh, std::string& hdrline)
		throw(HTTPMsgParsingError);


private:

};


}	// namespace HTTPTunnel

#endif

