/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An HTTP data reader.
 *
 * $Id: HTTPReader.hh,v 1.2 2008-07-25 12:14:53 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_READER_HH_
#define _HTTP_READER_HH_

#include "Reader.hh"
#include "Exceptions.hh"
#include "Payload.hh"

namespace HTTPTunnel {

class Connection;
class TunnelID;
class HTTPResponseMsg;

class HTTPReader : public Reader {
public:
	// Construction/destruction
	HTTPReader(Connection* conn);
	virtual ~HTTPReader();

	// Accessors
	virtual bool dataRemaining(void) const;


protected:

	/*********************/
	/* Types & Constants */
	/*********************/

	// Message parsing states
	enum ParseState { UNDEFINED, CONNECT, SEND, RECEIVE };

	// Number of message processing errors before we give up
	static const unsigned int		MAX_PROCESSING_ERRORS	= 25;

	// Msg parsing error levels
	static const unsigned int		PARSING_ERROR_MINOR		= 1;
	static const unsigned int		PARSING_ERROR_MAJOR		= 5;
	static const unsigned int		PARSING_ERROR_CRITICAL	= MAX_PROCESSING_ERRORS;


	/**************/
	/* Predicates */
	/**************/

	// Order message payloads by sequence number
	struct CmpSeqNo {
		bool operator()(const Payload* p1, const Payload* p2) {
			return (*p1 < *p2);
		}
	};


	/***********/
	/* Methods */
	/***********/

	// Process some newly read HTTP data
	virtual void processData(const unsigned char* data, unsigned int length)
		throw(ReadError);

	// Check a read message's HTTP response code
	void checkMsgResponseCode(HTTPResponseMsg* msg) throw(ReadError);

	// Deal with an error in HTTP msg processing
	bool msgError(unsigned int inc);


	/********/
	/* Data */
	/********/

	// A buffer for storing read data
	RawBuff								m_buff;

	// What type of HTTP message are we expecting next?
	ParseState							m_parseState;

	// Error tracking while trying to parse
	unsigned int						m_msgErrorCount;
	unsigned int						m_lastRecvdData;
	unsigned int						m_nextReqdData;
	unsigned int						m_lastErrLine;

};


}	// namespace

#endif

