/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an HTTP request message.
 *
 * $Id: HTTPRequestMsg.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_REQUEST_MSG_HH_
#define _HTTP_REQUEST_MSG_HH_

#include <string>
#include "HTTPMsg.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {

class HTTPMsgParms;
class ClientSideConfig;

class HTTPRequestMsg : public HTTPMsg {
public:
	// Construction/destruction
	HTTPRequestMsg();
	HTTPRequestMsg(const HTTPMsgParms* parms, std::string uri, const ClientSideConfig* cfg);
	HTTPRequestMsg(const HTTPRequestMsg& that);
	virtual ~HTTPRequestMsg();

	// Assignment
	HTTPRequestMsg& operator=(const HTTPRequestMsg& that);


	/***********/
	/* Methods */
	/***********/


protected:

	/***********/
	/* Methods */
	/***********/

	// Get start line string
	virtual std::string getStartLine(void) const;

	// Attempt to parse headers from a raw byte-stream
	virtual void parseHdrs(RawBuff& data, bool& eoh, std::string& hdrline)
		throw(HTTPMsgParsingError);

	// Get URL to include in request
	virtual std::string getRequestURI(void) const;


	/********/
	/* Data */
	/********/

	// URI for message
	std::string								m_uri;

	// Request line
	std::string								m_requestLine;

	// Reference to global client config
	const ClientSideConfig*				m_cfg;


private:

};


}	// namespace HTTPTunnel

#endif

