/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate an HTTP response message.
 *
 * $Id: HTTPResponseMsg.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_RESPONSE_MSG_HH_
#define _HTTP_RESPONSE_MSG_HH_

#include <string>
#include "Exceptions.hh"
#include "HTTPMsg.hh"

namespace HTTPTunnel {

class HTTPMsgParms;
class ServerSideConfig;

class HTTPResponseMsg : public HTTPMsg {
public:
	// Construction/destruction
	HTTPResponseMsg();
	HTTPResponseMsg(const HTTPMsgParms* parms, ServerSideConfig* cfg);
	HTTPResponseMsg(const HTTPResponseMsg& that);
	virtual ~HTTPResponseMsg();

	// Construction from a raw read data stream
	HTTPResponseMsg(RawBuff& readdata) throw(HTTPMsgParsingError);

	// Assignment
	HTTPResponseMsg& operator=(const HTTPResponseMsg& that);


	/***********/
	/* Methods */
	/***********/

	// Write ourselves out as a stream of bytes
	virtual void output(RawBuff& dest);

	// Accessors
	unsigned short getResponseCode(void) const;


protected:

	/***********/
	/* Methods */
	/***********/

	// Parse and extract any message content
	virtual void extractContent(RawBuff& readdata) throw(ParsingError);

	// Get start line string
	virtual std::string getStartLine(void) const;

	// Attempt to parse headers from a raw byte-stream
	virtual void parseHdrs(RawBuff& data, bool& eoh, std::string& hdrline)
		throw(HTTPMsgParsingError);


	/********/
	/* Data */
	/********/

	// Response code
	unsigned short							m_responseCode;

	// Response phrase
	std::string								m_responsePhrase;

	// Response line
	std::string								m_responseLine;

	// Reported message data length
	unsigned int							m_repContentLen;


private:

};


}	// namespace HTTPTunnel

#endif

