/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An HTTP data writer.
 *
 * $Id: HTTPWriter.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _HTTP_WRITER_HH_
#define _HTTP_WRITER_HH_

#include <vector>
#include "Writer.hh"
#include "Exceptions.hh"
#include "Mutex.hh"

namespace HTTPTunnel {

class Connection;
class HTTPMsg;
class MsgParms;
class HTTPMsgParms;
class ClientSideConfig;
class ServerSideConfig;

class HTTPWriter : public Writer {
public:
	// Construction/destruction
	HTTPWriter(Connection* conn);
	virtual ~HTTPWriter();


	/***********/
	/* Methods */
	/***********/

protected:

	/*********/
	/* Types */
	/*********/

	// States for message construction
	enum MsgState { UNDEFINED, INIT_CONNECT, RESP_CONNECT, RECEIVING, SENDING };


	/***********/
	/* Methods */
	/***********/

	// Attempt to process some data to send out
	virtual void processData(MsgParms* parms, RawBuff& out) throw(WriteError);

	// Construct appropriate HTTP message to encapsulate some data
	HTTPMsg* createMsg(HTTPMsgParms* parms) throw(WriteError);

	// Create a new URL for some request
	std::string createRequestURL(void);


	/********/
	/* Data */
	/********/

	// Our current message construction state
	MsgState										m_msgState;

	// Static data for generating unique URLS
	static std::vector<unsigned short>	c_requestStr;
	static Mutex								c_requestStrMtx;

};


}	// namespace

#endif

