/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Decrease tunnel error count.
 *
 * $Id: LeakTunnelErrorEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "LeakTunnelErrorEvent.hh"
#include "Tunneler.hh"
#include "Debug.hh"

namespace HTTPTunnel {


// Construction/destruction
LeakTunnelErrorEvent::LeakTunnelErrorEvent(const Time& time, Tunneler* tunneler)
: TimedEvent(time), m_tunneler(tunneler)
{
}

LeakTunnelErrorEvent::~LeakTunnelErrorEvent()
{
}


// Display event details for debugging
void LeakTunnelErrorEvent::details(std::stringstream& dbg)
{
	dbg << "LeakTunnelErrorEvent: ";
	TimedEvent::details(dbg);
}


// Decrease the error count
void LeakTunnelErrorEvent::execute(void)
{
	// Let tunnels controlling tunneler know
	m_tunneler->decreaseTunnelsErrorCount();
}


}	// namespace

