/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Perform logging to either stderr or syslog.
 *
 * $Id: Logger.hh,v 1.2 2008-11-09 18:50:21 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _LOGGER_HH_
#define _LOGGER_HH_

#include <unistd.h>
#include <syslog.h>
#include <string>
#include "Mutex.hh"

namespace HTTPTunnel {

class GlobalConfig;

class Logger {
public:
	// Construction/destruction
	Logger(std::string pname, bool time, bool syslog);
	~Logger();


	/*************************/
	/* Error logging methods */
	/*************************/

	// Error
	void error(std::string msg);
	// Warning
	void warn(std::string msg);
	// Info
	void info(std::string msg);


	/*************************/
	/* Trace logging methods */
	/*************************/

	void trace(std::string msg, unsigned int level);

private:

	/***********/
	/* Methods */
	/***********/

	// Get current debug level
	unsigned int getDebugLevel(void) const;

	// Get time as a tring for including in logging
	std::string getTimeStr(void) const;


	/*************/
	/* Constants */
	/*************/

	static const int ERR_FACILITY					= LOG_DAEMON;
	static const int TRACE_FACILITY				= LOG_DAEMON;


	/********/
	/* Data */
	/********/

	// The process name we were started with
	std::string					m_procName;

	// Whether we include timestamps in logging
	bool							m_time;

	// Whether we are logging to syslog
	bool							m_syslog;

	// Mutex to prevent interleaving output
	Mutex							m_mtx;

};


}		// namespace HTTPTunnel

#endif

