/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating a new HTTP msg has arrived.
 *
 * $Id: MsgArrivedEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "MsgArrivedEvent.hh"
#include "HTTPMsg.hh"
#include "Tunneler.hh"
#include "Debug.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {


// Construction/destruction
MsgArrivedEvent::MsgArrivedEvent(unsigned int connID, Tunneler* tunneler,
	HTTPMsg* msg)
: Event(), m_connID(connID), m_tunneler(tunneler), m_msg(msg)
{
}

MsgArrivedEvent::~MsgArrivedEvent()
{
	// We own HTTP msg, so free it up
	delete m_msg;
}


// Display event details for debugging
void MsgArrivedEvent::details(std::stringstream& dbg)
{
	dbg << "MsgArrivedEvent: ";
	Event::details(dbg);
}


// Report the shutdown
void MsgArrivedEvent::execute(void)
{
   DPRINTV("MsgArrivedEvent::execute()");

	try {
		// Let connections controlling tunneler know
		m_tunneler->messageArrived(m_connID, m_msg);
	}
	catch(LookupManagementError& e) {
		g_pLogger->warn("Failed to process message arrival event: " + e.what());
	}
}


}	// namespace

