/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate parameters for an HTTP message.
 *
 * $Id: MsgParms.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "MsgParms.hh"
#include "Payload.hh"
#include "Debug.hh"


namespace HTTPTunnel {


// Construction/destruction
MsgParms::MsgParms()
: m_tid(), m_payload(new Payload()), m_retry(false)
{
}

MsgParms::MsgParms(std::string tid, Payload* payload, bool retry)
: m_tid(tid), m_payload(payload), m_retry(retry)
{
}

MsgParms::MsgParms(const MsgParms& that)
: m_tid(that.m_tid), m_payload(0), m_retry(that.m_retry)
{
	try {
		// Copy payload
		m_payload = new Payload(*(that.m_payload));
	}
	catch(MemoryError& e) {
		g_pLogger->error("Error copying payload in MsgParms: " + e.what());
	}
}

MsgParms::~MsgParms()
{
	// Free payload
	delete m_payload;
	m_payload = 0;
}


// Assignment
MsgParms& MsgParms::operator=(const MsgParms& that)
{
	// Self assignment?
	if(this != &that) {
		m_tid = that.m_tid;
		m_retry = that.m_retry;

		// Free old payload
		delete m_payload;

		// Copy payload
		try {
			m_payload = new Payload(*(that.m_payload));
		}
		catch(MemoryError& e) {
			g_pLogger->error("Error copying payload in MsgParms: " + e.what());
		}
	}

	return *this;
}

// Clone
MsgParms* MsgParms::clone(void) const
{
	return new MsgParms(*this);
}


/*************/
/* Accessors */
/*************/
	

// Get tunnel ID
std::string MsgParms::getTid(void) const
{
	return m_tid;
}

// Get payload
const Payload* MsgParms::getPayload(void) const
{
	return m_payload;
}
Payload* MsgParms::getPayloadMutable(void)
{
	return m_payload;
}

// Get sending retry flag
bool MsgParms::getSendRetry(void) const
{
	return m_retry;
}


/************/
/* Mutators */
/************/


// Set tunnel ID
void MsgParms::setTid(std::string tid)
{
	m_tid = tid;
}


}	// namespace

