/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate parameters for a generic message.
 *
 * $Id: MsgParms.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _MSG_PARMS_HH_
#define _MSG_PARMS_HH_

#include <string>

namespace HTTPTunnel {

class Payload;

class MsgParms {
public:
	// Construction/destruction
	MsgParms();
	MsgParms(std::string tid, Payload* payload, bool retry);
	MsgParms(const MsgParms& that);
	virtual ~MsgParms();

	// Assignment
	MsgParms& operator=(const MsgParms& that);

	// Clone
	virtual MsgParms* clone(void) const;

	// Accessors
	std::string getTid(void) const;
	const Payload* getPayload(void) const;
	Payload* getPayloadMutable(void);
	bool getSendRetry(void) const;

	// Mutators
	void setTid(std::string tid);


protected:

	/********/
	/* Data */
	/********/

	// Tunnel ID
	std::string						m_tid;

	// Payload data
	Payload*                   m_payload;

	// Retry sending
	bool								m_retry;

};


}	// namespace

#endif

