/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Implement a pthreads mutex.
 *
 * $Id: Mutex.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <iostream>
#include <errno.h>
#include "Mutex.hh"

namespace HTTPTunnel {

// Construction/destruction
Mutex::Mutex() throw(MutexError)
{
   // Set attribute for recursive mutex
   if(pthread_mutexattr_init(&m_attr) != 0)
      throw MutexError("pthread_mutexattr_init() failed");
   if(pthread_mutexattr_settype(&m_attr, PTHREAD_MUTEX_RECURSIVE) != 0)
      throw MutexError("pthread_mutexattr_settype() failed");

   if(pthread_mutex_init(&m_mutex, &m_attr) != 0)
      throw MutexError("pthread_mutex_init() failed");
}

Mutex::~Mutex()
{
   pthread_mutex_destroy(&m_mutex);
}


// Lock the mutex
void Mutex::lock(void) throw(MutexError)
{
   if(pthread_mutex_lock(&m_mutex) != 0)
      throw MutexError("pthread_mutex_lock() failed");
}

// Unlock the mutex
void Mutex::unlock(void) throw(MutexError)
{
   if(pthread_mutex_unlock(&m_mutex) != 0)
      throw MutexError("pthread_mutex_unlock() failed");
}


// Return ptr to mutex we wrap
pthread_mutex_t* Mutex::getMtx(void)
{
   return &m_mutex;
}


}	// namespace

