/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a pthread mutex
 *
 * $Id: Mutex.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _MUTEX_HH_
#define _MUTEX_HH_

#include <pthread.h>
#include "Exceptions.hh"

namespace HTTPTunnel {

class Mutex {
public:
	// Construction/destruction
	Mutex() throw(MutexError);
	~Mutex();

	// Mutex management
	void lock(void) throw(MutexError);
	void unlock(void) throw(MutexError);

	// Accessors
	pthread_mutex_t* getMtx(void);


private:
	// Forbid assignment/copy construction
	Mutex(const Mutex&);
	Mutex& operator=(const Mutex&);

	// The pthreads mutex
	pthread_mutex_t		m_mutex;

	// Mutex attribute
	pthread_mutexattr_t	m_attr;

};


}		// namespace

#endif

