/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Exception safe mutex wrapper.
 *
 * $Id: MutexVar.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "Mutex.hh"
#include "MutexVar.hh"

namespace HTTPTunnel {

// Construction/destruction
MutexVar::MutexVar(Mutex& mtx) throw(MutexError)
: m_mtx(mtx), m_locked(false)
{
	// Created locked
	lock();
}

MutexVar::~MutexVar() throw(MutexError)
{
	// Unlock on deletion
	unlock();
}


// Lock mutex
void MutexVar::lock(void) throw(MutexError)
{
	m_mtx.lock();
	m_locked = true;
}

// Unlock mutex
void MutexVar::unlock(void) throw(MutexError)
{
	if(m_locked) {
		m_mtx.unlock();
		m_locked = false;
	}
}

// Return ptr to the mutex we wrap
pthread_mutex_t* MutexVar::getMtx(void)
{
	return m_mtx.getMtx();
}

// Indicate we are unlocked, eg; by a wait on a condition var
void MutexVar::released(void)
{
	m_locked = false;
}

// Indicate we are locked, eg; by a return from waiting on a condition var
void MutexVar::taken(void)
{
	m_locked = true;
}


}	// namespace

