/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Exception safe mutex.
 *
 * $Id: MutexVar.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _MUTEX_VAR_HH_
#define _MUTEX_VAR_HH_

#include <pthread.h>
#include "Mutex.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {

class MutexVar {

	friend class ConditionVar;

public:
	// Construction/destruction
	MutexVar(Mutex& mtx) throw(MutexError);
	~MutexVar() throw(MutexError);

	// Duplicate some mutex functions
	void lock(void) throw(MutexError);
	void unlock(void) throw(MutexError);

	// Accessors
	pthread_mutex_t* getMtx(void);

private:
	// Forbid copy construction / assignment
	MutexVar(const MutexVar&);
	MutexVar& operator=(const MutexVar&);

	// Manually indicate whether we are locked
	void released(void);
	void taken(void);

	// The mutex we wrap
	Mutex&		m_mtx;

	// For convenience, remember whether mutex is locked
	bool			m_locked;

};


}		// namespace

#endif

