/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * An event describing some new default tunnel parameters.
 *
 * $Id: NewTunnelParmsEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "NewTunnelParmsEvent.hh"
#include "Tunneler.hh"
#include "TunnelParms.hh"

namespace HTTPTunnel {


// Construction/destruction
NewTunnelParmsEvent::NewTunnelParmsEvent(Tunneler* tunneler, TunnelParms* parms,
	const TunnelerID& tunnelerID)
: Event(), m_tunneler(tunneler), m_parms(parms), m_tunnelerID(tunnelerID)
{
}

NewTunnelParmsEvent::~NewTunnelParmsEvent()
{
	// Free up parms
	delete m_parms;
}


// Display event details for debugging
void NewTunnelParmsEvent::details(std::stringstream& dbg)
{
	dbg << "NewTunnelParmsEvent: ";
	Event::details(dbg);
}


// Report the new parameters
void NewTunnelParmsEvent::execute(void)
{
	// Let connections controlling tunneler know
	m_tunneler->newTunnelParms(m_parms, m_tunnelerID);
}


}	// namespace

