/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate quotas for a tunnel.
 *
 * $Id: Quotas.cc,v 1.2 2008-06-26 09:47:29 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <cstdlib>
#include <vector>
#include "Quotas.hh"
#include "Utils.hh"
#include "Logger.hh"


namespace HTTPTunnel {


// Global references
extern Logger* g_pLogger;


// Construction/destruction
Quotas::Quotas()
: m_bandwidth(0), m_noTunnels(0)
{
}

Quotas::Quotas(unsigned int bandwidth, unsigned int noTunnels)
: m_bandwidth(bandwidth), m_noTunnels(noTunnels)
{
}

Quotas::Quotas(std::string qstr)
: m_bandwidth(0), m_noTunnels(0)
{
	// Parse quotas from string
	bool parsedOk = false;
	std::vector<std::string> quotas;
	Utils::SplitString(qstr, ",", quotas);
	if(quotas.size() > 0) {
		if(quotas.size() >= 1) {
			// Got bandwidth quota
			m_bandwidth = atoi(quotas[0].c_str());
		}
		if(quotas.size() >= 2) {
			// Got max number of tunnels quota
			m_noTunnels = atoi(quotas[1].c_str());
		}

		// Ok
		parsedOk = true;
	}

	// Managed to parse?
	if(!parsedOk) {
		g_pLogger->error("Bad quota string: " + qstr);
	}
}

Quotas::Quotas(const Quotas& that)
: m_bandwidth(that.m_bandwidth), m_noTunnels(that.m_noTunnels)
{
}

Quotas::~Quotas()
{
}


// Assignment
Quotas& Quotas::operator=(const Quotas& that)
{
	// Self assignment?
	if(this != &that) {
		m_bandwidth = that.m_bandwidth;
		m_noTunnels = that.m_noTunnels;
	}

	return *this;
}


// Equality
bool Quotas::operator==(const Quotas& that) const
{
	return (
		m_bandwidth == that.m_bandwidth &&
		m_noTunnels == that.m_noTunnels
	);
}


/*************/
/* Accessors */
/*************/


// Get bandwidth limit
unsigned int Quotas::getBandwidth(void) const
{
	return m_bandwidth;
}

// Get number of tunnels limit
unsigned int Quotas::getNoTunnels(void) const
{
	return m_noTunnels;
}


/************/
/* Mutators */
/************/


// Set bandwidth limit
void Quotas::setBandwidth(unsigned int bandwidth)
{
	m_bandwidth = bandwidth;
}

// Set number of tunnels limit
void Quotas::setNoTunnels(unsigned int noTunnels)
{
	m_noTunnels = noTunnels;
}


/******************/
/* Helper Methods */
/******************/


// Output to a stream
std::ostream& operator<<(std::ostream& str, const Quotas& quotas)
{
	unsigned int bandwidth = quotas.getBandwidth();
	unsigned int noTunnels = quotas.getNoTunnels();
	str << bandwidth << "," << noTunnels;
	return str;
}


}	// namespace

