/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate quotas for a tunnel.
 *
 * $Id: Quotas.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _QUOTAS_HH_
#define _QUOTAS_HH_

#include <ostream>
#include <string>

namespace HTTPTunnel {

class Quotas {
public:
	// Construction/destruction
	Quotas();
	Quotas(unsigned int bandwidth, unsigned int noTunnels);
	Quotas(std::string qstr);
	Quotas(const Quotas& that);
	~Quotas();

	// Operators
	Quotas& operator=(const Quotas& that);
	bool operator==(const Quotas& that) const;

	// Accessors
	unsigned int getBandwidth(void) const;
	unsigned int getNoTunnels(void) const;

	// Mutators
	void setBandwidth(unsigned int bandwidth);
	void setNoTunnels(unsigned int noTunnels);


private:

	/********/
	/* Data */
	/********/

	// The quotas we track
	unsigned int				m_bandwidth;
	unsigned int				m_noTunnels;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const Quotas& quotas);


}	// namespace

#endif
