/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Handle reading/writing for one end of a raw tunnel
 * connection.
 *
 * $Id: RawConnection.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _RAW_CONNECTION_HH_
#define _RAW_CONNECTION_HH_

#include "Connection.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Tunneler;

class RawConnection : public Connection {
public:
	// Construction/destruction
	RawConnection(Sock* sock, Tunneler* tunneler, const TunnelID& tid);
	RawConnection(Tunneler* tunneler, const TunnelID& tid);
	virtual ~RawConnection();

	// Prepare for a connect attempt to be made to the server
	virtual void connectAttempt(std::string host, unsigned int port,
		Enums::Protocol prot, bool ssl) throw(ConnectError);


protected:

	/***********/
	/* Methods */
	/***********/

	// Construct reader/writer
	virtual void createReaderWriter(void);


private:

	/********/
	/* Data */
	/********/

	// ID of tunnel we work for
	TunnelID								m_tid;

};


}	// namespace

#endif

