/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating some new raw data has arrived.
 *
 * $Id: RawDataArrivedEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "RawDataArrivedEvent.hh"
#include "Tunneler.hh"
#include "Debug.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {


// Construction/destruction
RawDataArrivedEvent::RawDataArrivedEvent(unsigned int connID, const TunnelID& tid,
	Tunneler* tunneler, const unsigned char* data, unsigned int length)
: Event(), IdentifyEvent<unsigned int>(connID), m_connID(connID), m_tid(tid),
  m_tunneler(tunneler), m_raw(data, length)
{
}

RawDataArrivedEvent::~RawDataArrivedEvent()
{
}


// Display event details for debugging
void RawDataArrivedEvent::details(std::stringstream& dbg)
{
	dbg << "RawDataArrivedEvent: ";
	Event::details(dbg);
}


// Report the shutdown
void RawDataArrivedEvent::execute(void)
{
	try {
		// Let connections controlling tunneler know
		m_tunneler->rawDataArrived(m_connID, m_tid, m_raw);
	}
	catch(LookupManagementError& e) {
		g_pLogger->warn("Failed to process raw data arrival event:" + e.what());
	}
}


// Get the raw data
const RawBuff& RawDataArrivedEvent::getRaw(void) const
{
	return m_raw;
}


// More new data
void RawDataArrivedEvent::moreData(const unsigned char* data, unsigned int length)
{
	m_raw.append(data, length);
}


}	// namespace

