/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating some new raw data has arrived.
 *
 * $Id: RawDataArrivedEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _RAW_DATA_ARRIVED_EVENT_HH_
#define _RAW_DATA_ARRIVED_EVENT_HH_

#include "Event.hh"
#include "IdentifyEvent.hh"
#include "TunnelID.hh"
#include "RawBuff.hh"

namespace HTTPTunnel {

class Tunneler;

class RawDataArrivedEvent : public Event, public IdentifyEvent<unsigned int> {
public:
	// Construction/destruction
	RawDataArrivedEvent(unsigned int connID, const TunnelID& tid, Tunneler* tunneler,
		const unsigned char* data, unsigned int length);
	virtual ~RawDataArrivedEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

	// Accessors
	const RawBuff& getRaw(void) const;

	// Mutators
	void moreData(const unsigned char* data, unsigned int length);

protected:

	// ID of connection data came in on
	unsigned int						m_connID;

	// ID of tunnel data is from
	TunnelID								m_tid;

	// Controlling tunneler
	Tunneler*							m_tunneler;

	// The data itself
	RawBuff								m_raw;

};


}	// namespace

#endif
