/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A raw data reader.
 *
 * $Id: RawReader.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "RawReader.hh"
#include "Debug.hh"
#include "Logger.hh"
#include "Exceptions.hh"
#include "Connection.hh"
#include "Tunneler.hh"
#include "RawDataArrivedEvent.hh"


namespace HTTPTunnel {


#ifdef DEBUG_LOG_DATA
// Reference to log file
extern std::ofstream* g_pRawReadLogFile;
extern unsigned int g_RawReadChars;
#endif

// Reference to the logger
extern Logger* g_pLogger;


// Construction/destruction
RawReader::RawReader(Connection* conn, const TunnelID& tid)
: Reader(conn), m_tid(tid)
{
	DPRINTV("RawReader::RawReader()");
}

RawReader::RawReader(Connection* conn)
: Reader(conn), m_tid()
{
	DPRINTV("RawReader::RawReader()");
}

RawReader::~RawReader()
{
	DPRINTV("RawReader::~RawReader()");
}


/********************/
/* Public Interface */
/********************/


// Set the tunnel ID we work for
void RawReader::setTunnelID(const TunnelID& tid)
{
	MutexVar mv(m_mtx);
	m_tid = tid;
}


/***********************/
/* Protected Interface */
/***********************/


// Process some newly read raw data - Caller hold mutex
void RawReader::processData(const unsigned char* data, unsigned int length)
	throw(ReadError)
{
	#ifdef DEBUG_LOG_DATA
	// Log read data
	RawBuff buff(data, length);
	logData(buff, g_pRawReadLogFile, g_RawReadChars);
	#endif

	// See if we have a raw payload event we can replace
	Tunneler* tunneler = m_conn->getTunneler();
	unsigned int connID = m_conn->getID();
	RawDataArrivedEvent* event = 0;
	event = tunneler->cancelAndGetEvent<RawDataArrivedEvent, unsigned int>(connID);
	if(event) {
		// Add data to this event
		event->moreData(data, length);
	}
	else {
		// Create new raw payload arrival event
		event = new RawDataArrivedEvent(connID, m_tid, tunneler, data, length);
	}

	// Schedule raw payload arrival event
	tunneler->scheduleEvent(event);
}


}	// namespace

