/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A raw data writer.
 *
 * $Id: RawWriter.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "RawWriter.hh"
#include "Debug.hh"
#include "Logger.hh"
#include "Exceptions.hh"
#include "Connection.hh"
#include "MsgParms.hh"
#include "Payload.hh"
#include "RawBuff.hh"


namespace HTTPTunnel {


#ifdef DEBUG_LOG_DATA
// Reference to log file
extern std::ofstream* g_pRawWriteLogFile;
extern unsigned int g_RawWriteChars;
#endif

// Reference to the logger
extern Logger* g_pLogger;


// Construction/destruction
RawWriter::RawWriter(Connection* conn)
: Writer(conn)
{
	DPRINTV("RawWriter::RawWriter()");
}

RawWriter::~RawWriter()
{
	DPRINTV("RawWriter::~RawWriter()");
}


/********************/
/* Public Interface */
/********************/


/***********************/
/* Protected Interface */
/***********************/


// Attempt to process some data to send out
void RawWriter::processData(MsgParms* parms, RawBuff& out) throw(WriteError)
{
	// Get data to process
	const RawBuff& in = parms->getPayload()->getPayload();
	if(in.getLength() > 0) {
		#ifdef DEBUG_TUN
		std::stringstream str;
		str << "RawWriter::processData() - Got " << in.getLength() << " bytes";
		DPRINTV(str.str());
		#endif

		#ifdef DEBUG_LOG_DATA
		// Log data
		logData(in, g_pRawWriteLogFile, g_RawWriteChars);
		#endif

		// Just append data from in to out
		out.append(in);
	}
	#ifdef DEBUG_TUN
	else {
		DPRINTV("RawWriter::processData() - Ignoring 0 length data");
	}
	#endif
}


}	// namespace

