/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Base class for data readers.
 *
 * $Id: Reader.hh,v 1.2 2008-07-25 12:14:53 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _READER_HH_
#define _READER_HH_

#ifdef DEBUG_LOG_DATA
#include <fstream>
#endif

#include "Exceptions.hh"
#include "Mutex.hh"
#include "RawBuff.hh"

namespace HTTPTunnel {

class Connection;

class Reader {
public:
	// Construction/destruction
	Reader(Connection* conn);
	virtual ~Reader();


	/***********/
	/* Methods */
	/***********/

	// Read and process some data from our socket
	virtual void read(void) throw(CommsError);

	// Accessors
	virtual bool dataRemaining(void) const;
	

protected:

	/***********/
	/* Methods */
	/***********/

	// Attempt to process some newly read data
	virtual void processData(const unsigned char* data, unsigned int length)
		throw(ReadError) = 0;

	#ifdef DEBUG_LOG_DATA
	// Log some newly read data
	void logData(const RawBuff& data, std::ofstream* file, unsigned int& lineChar);
	#endif


	/********/
	/* Data */
	/********/

	// A mutex
	Mutex									m_mtx;

	// Our controlling connection
	Connection*							m_conn;


private:

	/*************/
	/* Constants */
	/*************/

	// Size of socket read buffer
	static const unsigned int		READ_BUF_SIZE		= 16384;


	/********/
	/* Data */
	/********/

	// Our raw socket read buffer
	unsigned char						m_readbuff[READ_BUF_SIZE];

};


}	// namespace

#endif

