/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Tunnel controller for client end of tunnel acting as a
 * SOCKS proxy.
 *
 * $Id: SOCKSClientTunneler.hh,v 1.2 2008-11-21 17:59:39 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SOCKS_CLIENT_TUNNELER_HH_
#define _SOCKS_CLIENT_TUNNELER_HH_

#include <vector>
#include "ClientTunneler.hh"
#include "Exceptions.hh"


namespace HTTPTunnel {

class Tunnel;
class TunnelConfig;
class SOCKSConnection;

// A proxy client tunneler
class SOCKSClientTunneler : public ClientTunneler {
public:
	// Construction/destruction
	SOCKSClientTunneler(Server* server) throw(TunnelError);
	virtual ~SOCKSClientTunneler();


	/**********/
	/* Events */
	/**********/

	// Notification of a new socket connection
	virtual void newConnectionArrived(Sock* insock) throw(CommsError);

	// Notification that a connection has changed state
	virtual void connectionStateChange(unsigned int connID,
		Connection::ConnectionState state);

	// Notification that a tunnel has changed state
	virtual void tunnelStateChanged(const TunnelID& tid, Tunnel::TunnelState state);


protected:

	/***********/
	/* Methods */
	/***********/

	// Create config for tunnel to server
	TunnelConfig* createTunnelConfig(SOCKSConnection* inConn);


private:

};


}	// namespace

#endif

