/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A SOCKS data reader.
 *
 * $Id: SOCKSReader.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SOCKS_READER_HH_
#define _SOCKS_READER_HH_

#include <string>
#include "RawReader.hh"
#include "Exceptions.hh"
#include "RawBuff.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Connection;

class SOCKSReader : public RawReader {
public:
	// Construction/destruction
	SOCKSReader(Connection* conn);
	virtual ~SOCKSReader();

	// Accessors
	std::string getDestIP(void) const;
	unsigned int getDestPort(void) const;

	// Utilities
	void tunnelConnected(bool tunOk) throw(CommsError);


protected:

	/*********/
	/* Types */
	/*********/

	// SOCKS parsing states
	enum SOCKSState {
		SOCKS_VERSION, SOCKS_METHOD, SOCKS_REQUEST_RCV, SOCKS_REQUEST_RSP,
		SOCKS_CONNECTED
	};


	/***********/
	/* Methods */
	/***********/

	// Process some newly read raw data
	virtual void processData(const unsigned char* data, unsigned int length)
		throw(ReadError);


private:

	/***********/
	/* Methods */
	/***********/

	// SOCKS protocol handling
	void socksVersion(const unsigned char* data, unsigned int length)
		throw(ReadError);
	void socksRequestRcv(const unsigned char* data, unsigned int length)
		throw(ReadError);
	void socksRequestRsp(bool ok) throw(ReadError);

	// Send a SOCKS message
	void socksSendMsg(unsigned char* msg, size_t len) throw(ReadError);
	void socksSendMsg(std::vector<unsigned char>& msg) throw(ReadError);


	/********/
	/* Data */
	/********/

	// Current SOCKS parsing state
	SOCKSState					m_state;

	// A buffer for storing read data
	RawBuff						m_buff;

	// Fields from parsed SOCKS protocol
	unsigned char				m_version;
	std::string					m_destIP;
	unsigned int				m_destPort;
	unsigned char				m_atype;

};


}	// namespace

#endif

