/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to request a send of a HTTP message for some tunnel.
 *
 * $Id: SendMsgEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "SendMsgEvent.hh"
#include "Debug.hh"
#include "Tunneler.hh"

namespace HTTPTunnel {


// Construction/destruction
SendMsgEvent::SendMsgEvent(const Time& time, unsigned int connID, bool retry,
	const TunnelID& tid, Tunneler* tunneler)
: TimedEvent(time), IdentifyEvent<unsigned int>(connID), m_connID(connID),
  m_retry(retry), m_tid(tid), m_tunneler(tunneler)
{
}

SendMsgEvent::~SendMsgEvent()
{
}


// Display event details for debugging
void SendMsgEvent::details(std::stringstream& dbg)
{
	dbg << "SendMsgEvent: ";
	Event::details(dbg);
}


// Send the message
void SendMsgEvent::execute(void)
{
	DPRINTV("SendMsgEvent::execute()");

	// Let connections controlling tunneler do the send
	m_tunneler->sendTunnelMsg(m_tid, m_connID, m_retry);
}


}	// namespace

