/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event to request a send of a HTTP message for some tunnel.
 *
 * $Id: SendMsgEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SEND_MSG_EVENT_HH_
#define _SEND_MSG_EVENT_HH_

#include <string>
#include "TimedEvent.hh"
#include "IdentifyEvent.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Tunneler;

class SendMsgEvent : public TimedEvent, public IdentifyEvent<unsigned int> {
public:
	// Construction/destruction
	SendMsgEvent(const Time& time, unsigned int connID, bool retry,
		const TunnelID& tid, Tunneler* tunneler);
	virtual ~SendMsgEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

protected:

	/********/
	/* Data */
	/********/

	// ID of connection to send msg down
	unsigned int							m_connID;

	// Should we retry if sending fails?
	bool										m_retry;

	// ID of tunnel to send msg down
	TunnelID									m_tid;

	// Controlling tunneler
	Tunneler*								m_tunneler;

};


}	// namespace

#endif

