/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a payload sequence number.
 *
 * $Id: SeqNo.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "SeqNo.hh"


namespace HTTPTunnel {


// Construction/destruction
SeqNo::SeqNo()
: m_val(0)
{
}

SeqNo::SeqNo(unsigned long val)
: m_val(val)
{
}

SeqNo::SeqNo(const SeqNo& that)
: m_val(that.m_val)
{
}

SeqNo::~SeqNo()
{
}


/*************/
/* Operators */
/*************/


// Assignment
SeqNo& SeqNo::operator=(const SeqNo& that)
{
	// Self assignment?
	if(this != &that) {
		m_val = that.m_val;
	}

	return *this;
}

// Equality
bool SeqNo::operator==(const SeqNo& that) const
{
	return (m_val == that.m_val);
}

// Inequality
bool SeqNo::operator!=(const SeqNo& that) const
{
	return (m_val != that.m_val);
}

// Comparison
bool SeqNo::operator<(const SeqNo& that) const
{
	bool res = false;

	if(m_val < that.m_val) {
		// Have we wrapped?
		if((that.m_val - m_val) < (MAX_SEQ_NO / 2)) {
			res = true;
		}
	}
	else {
		// Have we wrapped?
		if((m_val - that.m_val) > (MAX_SEQ_NO / 2)) {
			res = true;
		}
	}

	return res;
}
bool SeqNo::operator>=(const SeqNo& that) const
{
	return !(operator<(that));
}

// Pre increment
SeqNo& SeqNo::operator++()
{
	if(++m_val > MAX_SEQ_NO)
		m_val = 1;
	return *this;
}


/*************/
/* Accessors */
/*************/


// Get our raw value
unsigned long SeqNo::getVal(void) const
{
	return m_val;
}

// Get our value as a string
std::string SeqNo::toString(void) const
{
	std::stringstream str;
	str << getVal();
	return str.str();
}

// Get highest sequence no we use
unsigned long SeqNo::getMaxSeqNo(void)
{
	return MAX_SEQ_NO;
}


/******************/
/* Helper Methods */
/******************/


// Output to a stream
std::ostream& operator<<(std::ostream& str, const SeqNo& seq)
{
	str << seq.getVal();
	return str;
}


}	// namespace


