/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a payload sequence number.
 *
 * $Id: SeqNo.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SEQ_NO_HH_
#define _SEQ_NO_HH_

#include <iostream>
#include <string>

namespace HTTPTunnel {

class SeqNo {
public:
	// Construction/destruction
	SeqNo();
	SeqNo(unsigned long val);
	SeqNo(const SeqNo& that);
	~SeqNo();

	// Operators
	SeqNo& operator=(const SeqNo& that);
	bool operator==(const SeqNo& that) const;
	bool operator!=(const SeqNo& that) const;
	bool operator<(const SeqNo& that) const;
	bool operator>=(const SeqNo& that) const;
	SeqNo& operator++();

	// Accessors
	unsigned long getVal(void) const;
	std::string toString(void) const;
	static unsigned long getMaxSeqNo(void);


private:

	/*************/
	/* Constants */
	/*************/

	// Value at which we roll-over
	static const unsigned long		MAX_SEQ_NO		= 999;


	/********/
	/* Data */
	/********/

	// Our current value
	unsigned long					m_val;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const SeqNo& seq);


}	// namespace

#endif

