/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A TCP/IP socket server to listen for incoming connections.
 *
 * $Id: Server.hh,v 1.4 2008-11-22 20:44:00 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SERVER_HH_
#define _SERVER_HH_

#include <vector>
#include "Exceptions.hh"
#include "ThreadManager.hh"
#include "Mutex.hh"
#include "ConditionVar.hh"
#include "TunnelStats.hh"

namespace HTTPTunnel {

class SideConfig;
class Tunneler;
class Sock;

class Server {
public:
	// Construction/destruction
	Server(SideConfig* serverConfig) throw(TunnelError);
	virtual ~Server();

	// Accessors
	const SideConfig* getConfig(void) const;
	SideConfig* getConfigMutable(void);
	Tunneler* getTunneler(void);
	void getTunnelStats(std::vector<TunnelStats>& stats);


protected:

	/*************/
	/* Constants */
	/*************/

	// Timeout (in miliseconds) to wait in poll()
	static const int			POLL_TIMEOUT		= 100;


	/***********/
	/* Methods */
	/***********/

	// Wait for arriving connections
	void startServer(void);

	// Configure our server socket
	void configureSocket(bool ssl) throw(TunnelError);


	/********/
	/* Data */
	/********/

	// Our main thread
	Thread*									m_thread;
	bool										m_shutDown;

	// Our server config
	SideConfig*								m_serverConfig;

	// Socket to listen for incoming connections
	Sock*										m_sock;

	// A Tunneler to handle tunneling
	Tunneler*								m_tunneler;

	// CondVars for synchronising with server thread start
	Mutex										m_serverThreadStartMtx;
	ConditionVar							m_serverThreadStartCond;
	Mutex										m_serverThreadContMtx;
	ConditionVar							m_serverThreadContCond;

	// A thread manager + Mutex
	ThreadManager							m_threadMgr;
	Mutex										m_mtx;

};


}	// namespace

#endif

