/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate settings for server authentication.
 *
 * $Id: ServerAuthSettings.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SERVER_AUTH_SETTINGS_HH_
#define _SERVER_AUTH_SETTINGS_HH_

#include <string>
#include "AuthSettings.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {

class ServerAuthSettings : public AuthSettings {
public:
	// Construction/destruction
	ServerAuthSettings();
	ServerAuthSettings(const ServerAuthSettings& that);
	virtual ~ServerAuthSettings();

	// Mutators
	void setServerSideAuth(AuthScheme scheme, std::string realm)
		throw(AuthProcessingError);

	// Construct tunneling headers
	virtual std::string getResponseHeader(std::string uri);

	// Reset state
	virtual void reset(void);


protected:

	/***********/
	/* Methods */
	/***********/

	// Get authorisation request header field identifier
	virtual std::string getAuthRequestHeaderID(void) const;


private:

	// Forbid assignment
	ServerAuthSettings& operator=(const ServerAuthSettings& that);

};


}	// namespace

#endif

