/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Interface for authenticating a user at the server, and
 * tracking/controling resource usage.
 *
 * $Id: ServerAuthenticator.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SERVER_AUTHENTICATOR_HH_
#define _SERVER_AUTHENTICATOR_HH_

#include <string>
#include <vector>
#include "Authenticator.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {

class Tunnel;
class ServerTunnel;
class ServerAuthSettings;

class ServerAuthenticator : public Authenticator {
public:
	// Construction/destruction
	ServerAuthenticator() throw(AuthError);
	virtual ~ServerAuthenticator();


	/*************/
	/* Accessors */
	/*************/

	// Get whether user is authenticated for some tunnel
	virtual bool getUserAuthenticated(std::string name, Tunnel* tun);


	/*************/
	/* Utilities */
	/*************/

	// Log tunnel details
	virtual unsigned int logNewConnection(ServerTunnel* tun);
	virtual void logCloseTunnel(ServerTunnel* tun);


protected:

	/***********/
	/* Methods */
	/***********/

	// Create a new tunnel user
	virtual User createUser(std::string name, bool keepCached);

	// Check a digest authentication response
	bool checkDigestAuthResponse(std::string& user, std::string& passwd,
		ServerAuthSettings* settings, const std::vector<std::string>& authArgs);

};


}	// namespace

#endif

