/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate server tunnel configuration settings in a handy blob.
 *
 * $Id: ServerConfigBlob.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "ServerConfigBlob.hh"
#include "Debug.hh"


namespace HTTPTunnel {


// Construction/destruction
ServerConfigBlob::ServerConfigBlob(std::string lhost, unsigned int lport, bool auth)
: ConfigBlob(), m_lhost(lhost), m_lport(lport), m_auth(auth), m_ssl(false),
  m_cert(""), m_certKey("")
{
}

ServerConfigBlob::ServerConfigBlob(std::string lhost, unsigned int lport, bool auth,
	std::string cert, std::string certKey)
: ConfigBlob(), m_lhost(lhost), m_lport(lport), m_auth(auth), m_ssl(true),
  m_cert(cert), m_certKey(certKey)
{
}

ServerConfigBlob::ServerConfigBlob(const ServerConfigBlob& that)
: ConfigBlob(that), m_lhost(that.m_lhost), m_lport(that.m_lport), m_auth(that.m_auth),
  m_ssl(that.m_ssl), m_cert(that.m_cert), m_certKey(that.m_certKey)
{
}

ServerConfigBlob::~ServerConfigBlob()
{
}


// Assignment
ServerConfigBlob& ServerConfigBlob::operator=(const ServerConfigBlob& that)
{
	if(this != &that) {
		// Base class
		ConfigBlob::operator=(that);

		// Our members
		m_lhost = that.m_lhost;
		m_lport = that.m_lport;
		m_auth = that.m_auth;
		m_ssl = that.m_ssl;
		m_cert = that.m_cert;
		m_certKey = that.m_certKey;
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get blob type
std::string ServerConfigBlob::getType(void) const
{
	return "SERVER";
}

// Get blob config as a parsable stream
std::string ServerConfigBlob::getConfig(void) const
{
	std::stringstream cfg;

	/* Format ourselves */

	// Local server listen address
	cfg << "listen ";
	if(m_lhost.size() > 0)
		cfg << m_lhost << " ";
	cfg << m_lport << std::endl;

	// Server authentication
	if(m_auth)
		cfg << "svrauth" << std::endl;

	// SSL certificate & key
	if(m_ssl)
		cfg << "ssl " << m_cert << " " << m_certKey << std::endl;

	// Firewall settings

	return cfg.str();
}


/************/
/* Mutators */
/************/


}	// namespace HTTPTunnel

