/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate server tunnel configuration settings in a handy blob.
 *
 * $Id: ServerConfigBlob.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SERVER_CONFIG_BLOB_HH_
#define _SERVER_CONFIG_BLOB_HH_

#include <string>
#include "ConfigBlob.hh"

namespace HTTPTunnel {

class ServerConfigBlob : public ConfigBlob {
public:
	// Construction/destruction
	ServerConfigBlob(std::string lhost, unsigned int lport, bool auth);
	ServerConfigBlob(std::string lhost, unsigned int lport, bool auth, std::string cert,
		std::string certKey);
	ServerConfigBlob(const ServerConfigBlob& that);
	virtual ~ServerConfigBlob();

	// Assignment
	ServerConfigBlob& operator=(const ServerConfigBlob& that);

	// Accessors
	virtual std::string getType(void) const;
	virtual std::string getConfig(void) const;

	// Mutators


protected:

	/********/
	/* Data */
	/********/

	// Local listening address/port
	std::string					m_lhost;
	unsigned int				m_lport;

	// Require clients to authenticate?
	bool							m_auth;

	// SSL settings
	bool							m_ssl;
	std::string					m_cert;
	std::string					m_certKey;

};


}	// namespace HTTPTunnel

#endif

