/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A server side TCP/IP socket server to listen for incoming connections.
 *
 * $Id: ServerServer.cc,v 1.5 2008-11-21 18:35:53 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "ServerServer.hh"
#include "ServerSideConfig.hh"
#include "ServerTunneler.hh"
#include "Debug.hh"


namespace HTTPTunnel {


// Construction/destruction
ServerServer::ServerServer(ServerSideConfig* serverConfig) throw(TunnelError)
: Server(serverConfig)
{
	DPRINTV("ServerServer::ServerServer()");

	// Take mutexes
	MutexVar stsMtx(m_serverThreadStartMtx);

	// Setup server socket
	configureSocket(serverConfig->getSSL());

	// Create server tunneler
	std::string err = "";
	try {
		m_tunneler = new ServerTunneler(this);
	}
	catch(TunnelError& e) {
		// Error creating tunneler
		err = "Error creating server tunneler: " + e.what();
	}

	// Wait for server thread to start
	m_serverThreadStartCond.wait(stsMtx);
	stsMtx.unlock();

	// Let server thread proceed with accepting connections
	MutexVar stcMtx(m_serverThreadContMtx);
	m_serverThreadContCond.signal();
	stcMtx.unlock();

	// If we had an error throw it now
	if(err.size() > 0) {
		throw TunnelError(err);
	}
}

ServerServer::~ServerServer()
{
	MutexVar mv(m_mtx);
}


}	// namespace

