/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all global configuration for
 * a server tunneler.
 *
 * $Id: ServerSideConfig.hh,v 1.4 2008-11-09 18:50:21 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _GLOBAL_SERVER_CONFIG_HH_
#define _GLOBAL_SERVER_CONFIG_HH_

#include <string>
#ifdef AUTH_FILE
#include <map>
#endif
#include "SideConfig.hh"
#include "Exceptions.hh"

namespace HTTPTunnel {

class Authenticator;
class ServerAuthenticator;
class Firewall;
class SockTunCallback;

class ServerSideConfig : public SideConfig {
public:
	// Construction/destruction
	#ifdef AUTH_FILE
	ServerSideConfig(bool ssl, bool sockTun, std::string cert, std::string certKey,
		std::string lhost, unsigned int lport, std::string firewallIPs,
		std::string firewallPorts, bool auth, std::map<std::string, std::string> &passwds,
		std::map<std::string, unsigned int> &tunnelnos,
		std::map<std::string, unsigned int> &bandwidths) throw(AuthError);
	#else
	ServerSideConfig(bool ssl, bool sockTun, std::string cert, std::string certKey,
		std::string lhost, unsigned int lport, std::string firewallIPs,
		std::string firewallPorts, bool auth) throw(AuthError);
	#endif

	virtual ~ServerSideConfig();


	/*************/
	/* Accessors */
	/*************/

	// Server config?
	virtual bool isServer(void) const;

	// Get firewall
	Firewall* getFirewall(void);

	// Get SSL certificate/key
	std::string getCertificate(void) const;
	std::string getCertificateKey(void) const;

	// Get user callback
	const SockTunCallback* getUserCallback(void) const;

	#ifdef AUTH_FILE
	std::string getPasswd(std::string);
	unsigned int getNoTunnels(std::string);
	unsigned int getBandwidth(std::string);
	#endif


	/************/
	/* Mutators */
	/************/

	// Turn authentication on/off
	void setAuthenticate(bool auth) throw(AuthError);

	// Set user callback
	void setUserCallback(const SockTunCallback* cb);


	/*************/
	/* Utilities */
	/*************/

	// Serialize to a file
	virtual void serialize(std::ofstream& file);

	// Create authenticator
	void createAuthenticator(void) throw(AuthError);


protected:

	/********/
	/* Data */
	/********/

	// Do we use authentication?
	bool							m_useAuth;

	// Firewall
	Firewall*					m_firewall;

	// SSL certificate & private key files
	std::string					m_cert;
	std::string					m_certKey;

	// Callback for user socket tunnel notifications
	SockTunCallback*			m_userCallback;

	#ifdef AUTH_FILE
	std::map<std::string, std::string>		m_passwds;
	std::map<std::string, unsigned int>		m_tunnelnos;
	std::map<std::string, unsigned int>		m_bandwidths;
	#endif

};


}	// namespace

#endif
