/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various parameters to be used by a ServerTunnel when tunneling.
 *
 * $Id: ServerTunnelParms.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "ServerTunnelParms.hh"


namespace HTTPTunnel {


// Construction/destruction
ServerTunnelParms::ServerTunnelParms(Tunnel::TunnelTestState testState,
	unsigned int payloadSize)
: TunnelParms(testState), m_payloadSize(payloadSize)
{
}

ServerTunnelParms::ServerTunnelParms(const ServerTunnelParms& that)
: TunnelParms(that), m_payloadSize(that.m_payloadSize)
{
}

ServerTunnelParms::~ServerTunnelParms()
{
}


// Assignment
ServerTunnelParms& ServerTunnelParms::operator=(const ServerTunnelParms& that)
{
	// Self assignment
	if(this != &that) {
		// Base class
		TunnelParms::operator=(that);

		// Our members
		m_payloadSize = that.m_payloadSize;
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get maximum payload size for the specified mode
unsigned int ServerTunnelParms::getMaxPayloadSize(bool useHeader) const
{
	return m_payloadSize;
}


}	// namespace

