/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to indicate it's time to shutdown a tunnel.
 *
 * $Id: ShutdownTunnelEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "ShutdownTunnelEvent.hh"
#include "Debug.hh"
#include "Tunneler.hh"

namespace HTTPTunnel {


// Construction/destruction
ShutdownTunnelEvent::ShutdownTunnelEvent(const Time& time, Tunneler* tunneler,
	const TunnelID& tid, bool otherEndInitiated)
: TimedEvent(time), IdentifyEvent<TunnelID>(tid), m_tunneler(tunneler), m_tid(tid),
  m_otherEndInitiated(otherEndInitiated)
{
}

ShutdownTunnelEvent::~ShutdownTunnelEvent()
{
}


// Display event details for debugging
void ShutdownTunnelEvent::details(std::stringstream& dbg)
{
	dbg << "ShutdownTunnelEvent: ";
	TimedEvent::details(dbg);
}


// Report the shutdown
void ShutdownTunnelEvent::execute(void)
{
	DPRINTV("ShutdownTunnelEvent::execute()");

	// Let tunnels controlling tunneler know
	m_tunneler->shutdownTunnel(m_tid, m_otherEndInitiated);
}


}	// namespace

