/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all global configuration for
 * one side of a tunneler.
 *
 * $Id: SideConfig.cc,v 1.2 2008-05-15 14:26:22 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "SideConfig.hh"
#include "Authenticator.hh"


namespace HTTPTunnel {


// Construction/destruction
SideConfig::SideConfig(Enums::Protocol prot, bool ssl, bool sockTun,
	std::string lhost, unsigned int lport)
: m_protocol(prot), m_ssl(ssl), m_sockTun(sockTun), m_listenIP(lhost),
  m_listenPort(lport), m_tunnelerID(this), m_authenticator(0)
{
}

SideConfig::~SideConfig()
{
	// Destroy authenticator
	if(m_authenticator) {
		delete m_authenticator;
		m_authenticator = 0;
	}
}


/*************/
/* Accessors */
/*************/


// Get protocol to use for server
Enums::Protocol SideConfig::getProtocol(void) const
{
	return m_protocol;
}

// Get whether to use SSL
bool SideConfig::getSSL(void) const
{
	return m_ssl;
}

// Get whether we are for a socket tunneler
bool SideConfig::isSockTun(void) const
{
	return m_sockTun;
}

// Get listen IP address
std::string SideConfig::getListenIP(void) const
{
	return m_listenIP;
}

// Get listen port
unsigned int SideConfig::getListenPort(void) const
{
	return m_listenPort;
}

// Get full listen address
std::string SideConfig::getListenAddr(void) const
{
	std::stringstream addr;
	addr << getListenIP() << ":" << getListenPort();
	return addr.str();
}

// Get tunneler ID
TunnelerID SideConfig::getTunnelerID(void) const
{
	return m_tunnelerID;
}

// Client config?
bool SideConfig::isClient(void) const
{
	return false;
}

// Server config?
bool SideConfig::isServer(void) const
{
	return false;
}

// Get authenticator
Authenticator* SideConfig::getAuthenticator(void)
{
	return m_authenticator;
}


/************/
/* Mutators */
/************/


// Set listen IP address
void SideConfig::setListenIP(std::string ip)
{
	m_listenIP = ip;
}

// Set listen port
void SideConfig::setListenPort(unsigned int lport)
{
	m_listenPort = lport;
}


}	// namespace

