/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a TCP/UDP socket.
 *
 * $Id: SockT.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <errno.h>
#include "MutexVar.hh"


namespace HTTPTunnel {


/***********************/
/* Protected Interface */
/***********************/


// Get socket options
template<class T>
void Sock::getSockOpt(int level, int optname, T& optres) throw(SockError)
{
	MutexVar mv(m_mtx);

	socklen_t reslen = sizeof(optres);
	if(getsockopt(m_fd, level, optname, &optres, &reslen) < 0)
		throw SockError("Failed to get socket option", errno);
}


// Set socket options
template<class T>
void Sock::setSockOpt(int level, int optname, T& optval) throw(SockError)
{
	MutexVar mv(m_mtx);

	if(setsockopt(m_fd, level, optname, &optval, sizeof(optval)) < 0)
		throw SockError("Failed to set socket option", errno);
}


}	// namespace

