/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate callbacks for socket tunnels.
 *
 * $Id: SockTunCallback.cc,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "SockTunCallback.hh"


namespace HTTPTunnel {


/**************/
/**************/
/* Base class */
/**************/
/**************/


// Construction/destruction
SockTunCallback::SockTunCallback()
{
}

SockTunCallback::SockTunCallback(const SockTunCallback& that)
{
}

SockTunCallback::~SockTunCallback()
{
}

// Assignment
SockTunCallback& SockTunCallback::operator=(const SockTunCallback& that)
{
	return *this;
}


/*******************/
/*******************/
/* Global Callback */
/*******************/
/*******************/
/*******************/


// Construction/destruction
GlobalSockTunCallback::GlobalSockTunCallback(GlobalCallbackFunc cb)
: SockTunCallback(), m_cb(cb)
{
}

GlobalSockTunCallback::GlobalSockTunCallback(const GlobalSockTunCallback& that)
: SockTunCallback(that), m_cb(that.m_cb)
{
}

GlobalSockTunCallback::~GlobalSockTunCallback()
{
}

// Assignment
GlobalSockTunCallback& GlobalSockTunCallback::operator=(const GlobalSockTunCallback& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assigment
		SockTunCallback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
	}

	return *this;
}

// Copy ourselves
SockTunCallback* GlobalSockTunCallback::clone(void) const
{
	return (new GlobalSockTunCallback(m_cb));
}

// Call the callback
void GlobalSockTunCallback::operator()(Sock* sock)
{
	(*m_cb)(sock);
}


}	// namespace


