/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate callbacks for socket tunnels.
 *
 * $Id: SockTunCallback.hh,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SOCK_TUN_CALLBACK_HH_
#define _SOCK_TUN_CALLBACK_HH_


namespace HTTPTunnel {

class Sock;

// Base class
class SockTunCallback {
public:
	// Construction/destruction
	SockTunCallback();
	SockTunCallback(const SockTunCallback& that);
	virtual ~SockTunCallback();

	// Assignment
	SockTunCallback& operator=(const SockTunCallback& that);

	// Copy ourselves
	virtual SockTunCallback* clone(void) const = 0;

	// Call the callback
	virtual void operator()(Sock* sock) = 0;

protected:

};


// Global callback
class GlobalSockTunCallback : public SockTunCallback {
private:
	// Types
	typedef void (*GlobalCallbackFunc)(Sock*);

public:
	// Construction/destruction
	GlobalSockTunCallback(GlobalCallbackFunc cb);
	GlobalSockTunCallback(const GlobalSockTunCallback& that);
	virtual ~GlobalSockTunCallback();

	// Assignment
	GlobalSockTunCallback& operator=(const GlobalSockTunCallback& that);

	// Copy ourselves
	virtual SockTunCallback* clone(void) const;

	// Call the callback
	virtual void operator()(Sock* sock);

protected:
	// The function to call
	GlobalCallbackFunc				m_cb;

};


// Class callback
template<class T>
class ClassSockTunCallback : public SockTunCallback {
private:
	// Types
	typedef void (T::*ClassCallbackMethod)(Sock*);

public:
	// Construction/destruction
	ClassSockTunCallback(ClassCallbackMethod cb, T* obj);
	ClassSockTunCallback(const ClassSockTunCallback& that);
	virtual ~ClassSockTunCallback();

	// Assignment
	ClassSockTunCallback& operator=(const ClassSockTunCallback& that);

	// Copy ourselves
	virtual SockTunCallback* clone(void) const;

	// Call the callback
	virtual void operator()(Sock* sock);

protected:
	// The method to call
	ClassCallbackMethod				m_cb;

	// Object to callback to
	T*										m_obj;

};


}	// namespace


// Include template methods
#include "SockTunCallbackT.cc"

#endif

