/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate callbacks for socket tunnels.
 *
 * $Id: SockTunCallbackT.cc,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "SockTunCallback.hh"

namespace HTTPTunnel {


/******************/
/******************/
/* Class Callback */
/******************/
/******************/


// Construction/destruction
template<class T>
ClassSockTunCallback<T>::ClassSockTunCallback(ClassCallbackMethod cb, T* obj)
: SockTunCallback(), m_cb(cb), m_obj(obj)
{
}

template<class T>
ClassSockTunCallback<T>::ClassSockTunCallback(const ClassSockTunCallback<T>& that)
: SockTunCallback(that), m_cb(that.m_cb), m_obj(that.m_obj)
{
}

template<class T>
ClassSockTunCallback<T>::~ClassSockTunCallback()
{
}

// Assignment
template<class T>
ClassSockTunCallback<T>& ClassSockTunCallback<T>::operator=(const ClassSockTunCallback<T>& that)
{
	// Self assignment?
	if(this != &that) {
		// Base class assignment
		SockTunCallback::operator=(that);

		// Copy our members
		m_cb = that.m_cb;
		m_obj = that.m_obj;
	}

	return *this;
}

// Return a copy of ourselves
template<class T>
SockTunCallback* ClassSockTunCallback<T>::clone(void) const
{
	return (new ClassSockTunCallback<T>(m_cb, m_obj));
}

// Call the callback
template<class T>
void ClassSockTunCallback<T>::operator()(Sock* sock)
{
	((*m_obj).*m_cb)(sock);
}


}	// namespace


