/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate client socket tunnel configuration settings in a handy
 * blob.
 *
 * $Id: SockTunClientConfigBlob.cc,v 1.1 2008-05-15 14:29:52 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "SockTunClientConfigBlob.hh"


namespace HTTPTunnel {


// Construction/destruction
SockTunClientConfigBlob::SockTunClientConfigBlob(Enums::Protocol prot, bool ssl,
	std::string shost, unsigned int sport)
: ClientConfigBlob(prot, ssl, "-", 0, shost, sport, "-", 0)
{
}

SockTunClientConfigBlob::SockTunClientConfigBlob(const SockTunClientConfigBlob& that)
: ClientConfigBlob(that)
{
}

SockTunClientConfigBlob::~SockTunClientConfigBlob()
{
}


// Assignment
SockTunClientConfigBlob& SockTunClientConfigBlob::operator=(const SockTunClientConfigBlob& that)
{
	if(this != &that) {
		// Base class
		ClientConfigBlob::operator=(that);
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get blob config as a parsable stream
std::string SockTunClientConfigBlob::getConfig(void) const
{
	std::stringstream cfg;

	/* Format ourselves */

	// Socket based tunneling
	cfg << "socktun" << std::endl;

	// Get base class formating
	cfg << ClientConfigBlob::getConfig();

	return cfg.str();
}


}	// namespace HTTPTunnel

