/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * A server to accept incoming socket tunnel connections.
 *
 * $Id: SockTunServer.cc,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "SockTunServer.hh"
#include "Debug.hh"
#include "Logger.hh"
#include "MutexVar.hh"
#include "Sock.hh"


namespace HTTPTunnel {


// Global references
extern Logger* g_pLogger;


// Construction/destruction
SockTunServer::SockTunServer(const SockTunCallback* userCallback) throw(TunnelError)
: m_mtx(), m_sock(0), m_prot(Enums::TCP), m_listenIP("127.0.0.1"), m_listenPort(0),
  m_userCallback(userCallback->clone()), m_thread(0), m_shutDown(false)
{
	DPRINTV("SockTunServer::SockTunServer()");
}

SockTunServer::~SockTunServer()
{
	DPRINTV("SockTunServer::~SockTunServer()");

	MutexVar mv(m_mtx);

	// Free listening socket
	if(m_sock) {
		delete m_sock;
		m_sock = 0;
	}

	// Free user callback
	if(m_userCallback) {
		delete m_userCallback;
		m_userCallback = 0;
	}
}


/*************/
/* Accessors */
/*************/


// Get address we are listening on
std::string SockTunServer::getListenIP(void) const
{
	return m_listenIP;
}

// Get port we are listening on
unsigned int SockTunServer::getListenPort(void) const
{
	return m_listenPort;
}

// Get protocol we're using
Enums::Protocol SockTunServer::getProtocol(void) const
{
	return m_prot;
}


/***********************/
/* Protected Interface */
/***********************/


// Make callback to user
void SockTunServer::callbackToUser(Sock* sock)
{
	MutexVar mv(m_mtx);

	// Got a callback?
	if(m_userCallback) {
		DPRINTV("SockTunServer::callbackToUser() - Invoking user callback");

		// Do the callback
		(*m_userCallback)(sock);
	}
}


}	// namespace


