/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * A server to accept incoming socket tunnel connections.
 *
 * $Id: SockTunServer.hh,v 1.2 2009-03-20 11:52:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SOCK_TUN_SERVER_HH_
#define _SOCK_TUN_SERVER_HH_

#include <string>
#include "Exceptions.hh"
#include "Mutex.hh"
#include "Enums.hh"
#include "SockTunCallback.hh"
#include "Thread.hh"

namespace HTTPTunnel {

class Sock;

class SockTunServer {
public:
	// Construction/destruction
	SockTunServer(const SockTunCallback* userCallback) throw(TunnelError);
	virtual ~SockTunServer();

	// Accessors
	std::string getListenIP(void) const;
	unsigned int getListenPort(void) const;
	Enums::Protocol getProtocol(void) const;


protected:

	/*************/
	/* Constants */
	/*************/

	// Timeout (in miliseconds) between poll()s
	static const int				POLL_TIMEOUT		= 10;


	/***********/
	/* Methods */
	/***********/

	// Make callback to user
	void callbackToUser(Sock* sock);


	/********/
	/* Data */
	/********/

	// Mutex
	Mutex										m_mtx;

	// Socket to listen on
	Sock*										m_sock;
	Enums::Protocol						m_prot;

	// Address we are listening on
	std::string								m_listenIP;
	unsigned int							m_listenPort;

	// Callback to user
	SockTunCallback*						m_userCallback;

	// Connection handling thread details
	Thread*									m_thread;
	bool										m_shutDown;

};


}	// namespace

#endif

