/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate server socket tunnel configuration settings in a handy
 * blob.
 *
 * $Id: SockTunServerConfigBlob.cc,v 1.1 2008-05-15 14:29:52 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "SockTunServerConfigBlob.hh"
#include "SockTunCallback.hh"


namespace HTTPTunnel {


// Construction/destruction
SockTunServerConfigBlob::SockTunServerConfigBlob(std::string lhost, unsigned int lport,
	bool auth, SockTunCallback* userCallback)
: ServerConfigBlob(lhost, lport, auth), m_userCallback(userCallback)
{
}

SockTunServerConfigBlob::SockTunServerConfigBlob(std::string lhost, unsigned int lport,
	bool auth, std::string cert, std::string certKey, SockTunCallback* userCallback)
: ServerConfigBlob(lhost, lport, auth, cert, certKey), m_userCallback(userCallback)
{
}

SockTunServerConfigBlob::SockTunServerConfigBlob(const SockTunServerConfigBlob& that)
: ServerConfigBlob(that), m_userCallback(0)
{
	// Copy callback
	if(that.m_userCallback)
		m_userCallback = that.m_userCallback->clone();
}

SockTunServerConfigBlob::~SockTunServerConfigBlob()
{
	// We own the user callback
	if(m_userCallback) {
		delete m_userCallback;
		m_userCallback = 0;
	}
}


// Assignment
SockTunServerConfigBlob& SockTunServerConfigBlob::operator=(const SockTunServerConfigBlob& that)
{
	if(this != &that) {
		// Base class
		ServerConfigBlob::operator=(that);

		// Our members
		if(m_userCallback) {
			delete m_userCallback;
			m_userCallback = 0;
		}
		if(that.m_userCallback)
			m_userCallback = that.m_userCallback->clone();
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get blob config as a parsable stream
std::string SockTunServerConfigBlob::getConfig(void) const
{
	std::stringstream cfg;

	/* Format ourselves */

	// Socket based tunneling
	cfg << "socktun" << std::endl;

	// Get base class formating
	cfg << ServerConfigBlob::getConfig();

	return cfg.str();
}

// Get callback to user
const SockTunCallback* SockTunServerConfigBlob::getUserCallback(void) const
{
	return m_userCallback;
}


}	// namespace HTTPTunnel

