/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate a TCP socket.
 *
 * $Id: TCPSock.hh,v 1.3 2008-11-21 17:59:39 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TCP_SOCK_HH_
#define _TCP_SOCK_HH_

#include "Sock.hh"

namespace HTTPTunnel {

class TCPSock : public Sock {
public:
	// Construction/destruction
	TCPSock(bool blocking = false) throw(SockError);
	TCPSock(int fd, std::string cliAddr) throw(SockError);
	virtual ~TCPSock();

	// Utilities
	virtual void newConnection(Tunneler* tunneler) throw(SockError);
	virtual void listen(void) throw(SockError);
	virtual Sock* accept(void) throw(SockError);
	virtual void connect(std::string addr, unsigned int port) throw(SockError, CommsError);
	virtual int read(unsigned char* buff, size_t buffSize) throw(SockError, CommsError);
	virtual int write(const unsigned char* buff, size_t buffSize) throw(SockError, CommsError);
	virtual void getConnectResult(bool& resultAvailable, bool& connected) throw(SockError);


protected:

private:

	// Forbid copying
	TCPSock(const TCPSock& that);
	TCPSock& operator=(const TCPSock& that);

};


}	// namespace

#endif

