/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Client side Tunnel for testing.
 *
 * $Id: TestClientTunnel.hh,v 1.2 2008-05-23 11:24:57 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TEST_CLIENT_TUNNEL_HH_
#define _TEST_CLIENT_TUNNEL_HH_

#include "ClientTunnel.hh"
#include "TestTunnel.hh"
#include "ClientTunnelParms.hh"

namespace HTTPTunnel {

class TestClientTunnel : public ClientTunnel, public TestTunnel {
public:
	// Construction/destruction
	TestClientTunnel(TunnelConfig* tcfg, ClientTunneler* tunneler);
	virtual ~TestClientTunnel();


	/*************/
	/* Accessors */
	/*************/

	// Get default tunneling parameters
	static ClientTunnelParms getDefaultTunParms(void);

	// Get whether we are a test tunnel
	virtual bool isTestTunnel(void) const;

	// Get whether we have completed these tests
	bool testsCompleted(void);


	/************/
	/* Mutators */
	/************/

	// Record connection error
	virtual void recordConnectionError(TunnelErrorType errType);


protected:

	/********************/
	/* Tunnel Interface */
	/********************/

	/***********/
	/* Methods */
	/***********/

	// Create payload for tunneled msg to send to the destination
	virtual void makeTunnelPayload(RawBuff& data, bool& split, unsigned int max)
		throw(MemoryError);

	// Check message parms before resending
	virtual void checkResendMsgParms(HTTPMsgParms* parms);

	// Advance our internal state machine
	virtual void advanceState(const HTTPMsgParms* parms);

	// A sent message has been acknowledged
	virtual void msgAcked(SentMsgParms* parms);

	// Record we need to resend a msg - Caller holds mutex
	virtual void needToResendMsg(const SeqNo& seqNo, bool msgLost);


	/************************/
	/* TestTunnel Interface */
	/************************/

	/***********/
	/* Methods */
	/***********/

	// Move testing on
	virtual void nextTest(bool ok);

	// Inform controlling tunneler of our test results
	virtual void sendTestResults(void);


private:

	/*********/
	/* Types */
	/*********/

	// Test states
	enum ClientTestType { CTEST_IDLE, CTEST_URLMAXSIZE, CTEST_BODYMAXSIZE };


	/*************/
	/* Constants */
	/*************/

	// Maximum/minimum payload length for created HTTP messages
	static const unsigned int		MIN_TEST_BODY_PAYLOAD		= 512;
	static const unsigned int		MAX_TEST_BODY_PAYLOAD		= MIN_TEST_BODY_PAYLOAD * 32;
	static const unsigned int		MIN_TEST_URL_PAYLOAD			= 128;
	static const unsigned int		MAX_TEST_URL_PAYLOAD			= MIN_TEST_URL_PAYLOAD * 32;

	// Default payload length for created HTTP messages
	static const unsigned int		DEFAULT_BODY_PAYLOAD			= 8192;
	static const unsigned int		DEFAULT_URL_PAYLOAD			= 1024;


	/********/
	/* Data */
	/********/

	// What type of testing are we doing?
	ClientTestType							m_testType;

	// Last known good test parameters
	unsigned int							m_goodURLPayloadSize;
	unsigned int							m_goodBodyPayloadSize;

	// Current test parameters
	unsigned int							m_currURLPayloadSize;
	unsigned int							m_currBodyPayloadSize;

};


}	// namespace

#endif

