/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Server side Tunnel for testing.
 *
 * $Id: TestServerTunnel.hh,v 1.2 2008-05-23 11:24:57 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TEST_SERVER_TUNNEL_HH_
#define _TEST_SERVER_TUNNEL_HH_

#include "ServerTunnel.hh"
#include "TestTunnel.hh"
#include "ServerTunnelParms.hh"

namespace HTTPTunnel {

class TestServerTunnel : public ServerTunnel, public TestTunnel {
public:
	// Construction/destruction
	TestServerTunnel(TunnelConfig* tcfg, ServerTunneler* tunneler);
	virtual ~TestServerTunnel();


	/*************/
	/* Accessors */
	/*************/

	// Get default tunneling parameters
	static ServerTunnelParms getDefaultTunParms(void);

	// Get whether we are a test tunnel
	virtual bool isTestTunnel(void) const;


	/************/
	/* Mutators */
	/************/

	// Record connection error
	virtual void recordConnectionError(TunnelErrorType errType);


protected:

	/********************/
	/* Tunnel Interface */
	/********************/

	/***********/
	/* Methods */
	/***********/

	// Create payload for tunneled msg to send to the destination
	virtual void makeTunnelPayload(RawBuff& data, bool& split, unsigned int max)
		throw(MemoryError);

	// Check message parms before resending
	virtual void checkResendMsgParms(HTTPMsgParms* parms);

	// Advance our internal state machine
	virtual void advanceState(const HTTPMsgParms* parms);

	// A sent message has been acknowledged
	virtual void msgAcked(SentMsgParms* parms);

	// Record we need to resend a msg - Caller holds mutex
	virtual void needToResendMsg(const SeqNo& seqNo, bool msgLost);


	/************************/
	/* TestTunnel Interface */
	/************************/

	/***********/
	/* Methods */
	/***********/

	// Move testing on
	virtual void nextTest(bool ok);

	// Inform controlling tunneler of our test results
	virtual void sendTestResults(void);


private:

	/*********/
	/* Types */
	/*********/

	// Test states
	enum ServerTestType { STEST_IDLE, STEST_PAYLOADMAXSIZE };


	/*************/
	/* Constants */
	/*************/

	// Maximum/minimum payload length for created HTTP messages
	static const unsigned int		MIN_TEST_PAYLOAD				= 1024;
	static const unsigned int		MAX_TEST_PAYLOAD				= MIN_TEST_PAYLOAD * 32;

	// Default payload length for created HTTP messages
	static const unsigned int		DEFAULT_PAYLOAD				= 16384;


	/********/
	/* Data */
	/********/

	// What type of testing are we doing?
	ServerTestType						m_testType;

	// Last known good test parameters
	unsigned int						m_goodPayloadSize;

	// Current test parameters
	unsigned int						m_currPayloadSize;

};


}	// namespace

#endif

