/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A thread specific data item.
 *
 * $Id: ThreadData.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _THREAD_DATA_HH_
#define _THREAD_DATA_HH_

#include <pthread.h>
#include "Exceptions.hh"

namespace HTTPTunnel {

template<class T> class ThreadData {
public:
	// Construction/destruction
	ThreadData() throw(ThreadDataError);
	~ThreadData();

	// Conversion to T
	operator T() const;

	// Set the thread specific data value
	void operator=(const T& val) throw(ThreadDataError);

	// Free any thread specific data held for the current thread
	void free(void);

private:
	// Forbid copy construction/assignment
	ThreadData(const ThreadData&);
	ThreadData& operator=(const ThreadData&);

	// The shared pthread key
	pthread_key_t			m_key;

};

#include "ThreadDataT.cc"

}				// namespace

#endif		// _THREAD_DATA_HH_

