/* (C) Richard Mills / The Linux Academy Ltd.
 *
 * A thread specific data item.
 *
 * $Id: ThreadDataT.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 * 
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "ThreadData.hh"


namespace HTTPTunnel {


// Construction/destruction
template<class T>
ThreadData<T>::ThreadData() throw(ThreadDataError)
{
	// Construct key
	if(pthread_key_create(&m_key, 0) != 0)
		throw ThreadDataError("pthread_key_create() failed");
}

template<class T>
ThreadData<T>::~ThreadData()
{
	// Destroy key
	pthread_key_delete(m_key);
}

// Conversion to T
template<class T>
ThreadData<T>::operator T() const
{
	// Get value
	T* valPtr = (T*)pthread_getspecific(m_key);

	// Protect against using unset value
	if(!valPtr)
		return 0;

	return *valPtr;
}

// Set the thread specific data value
template<class T>
void ThreadData<T>::operator=(const T& val) throw(ThreadDataError)
{
	// First check we don't already have a value
	free();

	// Take a copy of the data
	T* newVal = new T(val);

	// Set the new value
	if(pthread_setspecific(m_key, newVal) != 0)
		throw ThreadDataError("pthread_setspecific() failed");
}

// Free any thread specific data held for the current thread
template<class T>
void ThreadData<T>::free(void)
{
	T* oldVal = (T*)pthread_getspecific(m_key);
	if(oldVal) {
		// Free memory taken up by old value
		delete oldVal;
	}
}


}		// namespace

