/* (C) 2003 Kevin Manning.
 * (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Thread Manager class.
 *
 * $Id: ThreadManager.hh,v 1.2 2008-11-09 18:50:21 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _THREAD_MANAGER_HH_
#define _THREAD_MANAGER_HH_

#include <pthread.h>
#include <vector>
#include "Exceptions.hh"
#include "Thread.hh"
#include "Callback.hh"
#include "Mutex.hh"
#include "ConditionVar.hh"

namespace HTTPTunnel {

// A wrapper for thread details
class ThreadDetails {
public:
	ThreadDetails(Thread* thread);
	~ThreadDetails();

	// Get/set thread
	Thread* getThread(void) const;
	void setThread(Thread* thread);

private:

	// The thread these details are for
	Thread*			  m_thread;

};


// A thread manager
class ThreadManager {

	friend class Thread;

public:
	// Construction/Destruction
	ThreadManager() throw(MutexError);
	~ThreadManager();

	// Thread management
	Thread* newThread(Callback& callBack) throw(ThreadError);
	void shutdown(void);

private:

	/*********/
	/* Types */
	/*********/

	// Predicate for looking up thread details from thread
	struct PredGetDetails {
		PredGetDetails(Thread* thread) : m_thread(thread) {}
		bool operator()(const ThreadDetails* details) const {
			return (details->getThread() == m_thread);
		}
		Thread* m_thread;
	};


	/***********/
	/* Methods */
	/***********/

	// Callbacks for thread to let us know how it's doing
	void started(Thread* thread);
	void finished(Thread* thread);
	void waitForAll(MutexVar& mv);


	/********/
	/* Data */
	/********/

	// Flag to indicate if we are active
	bool										m_active;

	// The set of managed threads
	std::vector<ThreadDetails*>		m_threadDetails;

	// Local mutex
	Mutex										m_mtx;

	// Condition var for thread to let us know it's finished
	ConditionVar							m_cv_thread_finished;

};


}		// namespace

#endif

