/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Represent a time in seconds & milli-seconds.
 *
 * $Id: Time.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TIME_HH_
#define _TIME_HH_

#include <sys/time.h>
#include <iostream>
#include <time.h>

namespace HTTPTunnel {

class Time {
public:
	// Construction/destruction
	Time(time_t secs, unsigned int millis = 0);
	Time(time_t secs, unsigned int millis, bool abs);
	Time(const Time& that);
	~Time();

	// Operators
	Time& operator=(const Time& that);
	Time operator-(const Time& that) const;
	Time operator+(const Time& that) const;
	bool operator==(const Time& that) const;
	bool operator<(const Time& that) const;

	// Get current time
	static Time now(void);


	/***********/
	/* Methods */
	/***********/

	// Accessors
	const struct timeval& getTimeVal(void) const;
	time_t getSecs(void) const;
	unsigned int getMillis(void) const;
	unsigned int getTotalMillis(void) const;

	// Mutators
	void subInterval(time_t secs, unsigned int millis);
	void addInterval(time_t secs, unsigned int millis);

	// Utilities
	bool elapsed(void) const;
	std::string toString(void) const;


private:

	/*************/
	/* Constants */
	/*************/

	// Conversion facter between micro/milli seconds
	static const int					MILLISCALE		= 1000;


	/********/
	/* Data */
	/********/

	// Timeval to represent time
	struct timeval						m_timeVal;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const Time& time);


}	// namespace

#endif

