/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate tunable parameters for a tunnel.
 *
 * $Id: TuneSettings.hh,v 1.2 2009-02-27 11:56:19 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNE_SETTINGS_HH_
#define _TUNE_SETTINGS_HH_

#include <ostream>
#include <string>

namespace HTTPTunnel {

class TuneSettings {
public:

	/*************/
	/* Constants */
	/*************/

	// Absolute maximum no. of oustanding unacked msgs
	static const unsigned int		MAX_UNACKED_MSGS			= 5;


	/***********/
	/* Methods */
	/***********/

	// Construction/destruction
	TuneSettings();
	TuneSettings(std::string tune);
	TuneSettings(const TuneSettings& that);
	~TuneSettings();

	// Assignment
	TuneSettings& operator=(const TuneSettings& that);

	// Accessors
	std::string getTuneDesc(void) const;
	unsigned int getMaxUnackedMsgs(void) const;
	unsigned int getFastPollTimeout(void) const;
	unsigned int getMediumPollTimeout(void) const;
	unsigned int getSlowPollTimeout(void) const;
	unsigned int getMaxPollTimeout(void) const;


private:

	/*************/
	/* Constants */
	/*************/

	// Absolute maximum poll timeout (milli-seconds)
	static const unsigned int		MAX_POLL_TIMEOUT					= 2500;

	// Maximum numbers of outstanding unacked msgs
	static const unsigned int		DFLT_MAX_UNACKED_MSGS			= 1;
	static const unsigned int		BRST_MAX_UNACKED_MSGS			= 1;
	static const unsigned int		RLTM_MAX_UNACKED_MSGS			= 1;

	// Time between poll timeout events (milli-seconds)
	static const unsigned int		DFLT_FAST_POLL_TIMEOUT			= 200;
	static const unsigned int		DFLT_MEDIUM_POLL_TIMEOUT		= 250;
	static const unsigned int		DFLT_SLOW_POLL_TIMEOUT			= 500;
	static const unsigned int		DFLT_MAX_POLL_TIMEOUT			= MAX_POLL_TIMEOUT;

	static const unsigned int		BRST_FAST_POLL_TIMEOUT			= 250;
	static const unsigned int		BRST_MEDIUM_POLL_TIMEOUT		= 500;
	static const unsigned int		BRST_SLOW_POLL_TIMEOUT			= 2000;
	static const unsigned int		BRST_MAX_POLL_TIMEOUT			= MAX_POLL_TIMEOUT;

	static const unsigned int		RLTM_FAST_POLL_TIMEOUT			= 50;
	static const unsigned int		RLTM_MEDIUM_POLL_TIMEOUT		= 100;
	static const unsigned int		RLTM_SLOW_POLL_TIMEOUT			= 200;
	static const unsigned int		RLTM_MAX_POLL_TIMEOUT			= 500;


	/***********/
	/* Methods */
	/***********/

	// Set tuning settings based on the tuning description
	void setup(void);


	/********/
	/* Data */
	/********/

	// Tuning description
	std::string					m_tune;

	// Maximum no. of unacked msgs
	unsigned int				m_tunedMaxUnackedMsgs;

	// Poll timeouts
	unsigned int				m_tunedFastPollTimeout;
	unsigned int				m_tunedMediumPollTimeout;
	unsigned int				m_tunedSlowPollTimeout;
	unsigned int				m_tunedMaxPollTimeout;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const TuneSettings& settings);


}	// namespace

#endif

