/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all per tunnel configuration.
 *
 * $Id: TunnelConfig.hh,v 1.2 2008-07-11 11:22:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_CONFIG_HH_
#define _TUNNEL_CONFIG_HH_

#include <string>
#include "Mutex.hh"
#include "Enums.hh"
#include "TuneSettings.hh"

namespace HTTPTunnel {

class TunnelID;
class ProxySettings;
class ServerAuthSettings;

class TunnelConfig {
public:
	// Construction/destruction
	TunnelConfig(TunnelID* tid, std::string tune, const ProxySettings* proxyCfg,
		const ServerAuthSettings* saCfg, std::string destIP, unsigned int destPort);
	TunnelConfig(TunnelID* tid, std::string tune, std::string destAddr,
		const ServerAuthSettings* saCfg);
	~TunnelConfig();

	// Accessors
	const TunnelID* getTunnelID(void) const;
	std::string getHTTPVersion(void) const;
	std::string getDestIP(void) const;
	unsigned int getDestPort(void) const;
	Enums::Protocol getDestProtocol(void) const;
	std::string getDestAddress(void) const;
	bool getUseHeaders(void) const;
	ProxySettings* getProxySettings(void);
	ServerAuthSettings* getServerAuthSettings(void);
	const TuneSettings& getTuning(void) const;

	// Mutators
	void setHTTPVersion(std::string ver);
	void setDestIP(std::string destIP);
	void setDestPort(unsigned int destPort);
	void setDestAddress(std::string addr);
	void setUseHeaders(bool uh);


private:

	/********/
	/* Data */
	/********/

	// A mutex
	Mutex									m_mtx;

	// The tunnel ID
	TunnelID*							m_tid;

	// HTTP version we're using over this tunnel
	std::string							m_httpVer;

	// Address of ultimate destination
	std::string							m_destIP;
	unsigned int						m_destPort;

	// Are we using headers for tunneling?
	bool									m_useHeaders;

	// Proxy/serverauth settings for this tunnel
	ProxySettings*						m_proxyCfg;
	ServerAuthSettings*				m_serverAuthCfg;

	// Tunnel tuning
	TuneSettings						m_tuning;

};


}	// namespace

#endif

