/* (C) 2009 Richard Mills / The Linux Academy Ltd.
 *
 * An event to indicate a tunnel has been destroyed.
 *
 * $Id: TunnelDestroyedEvent.hh,v 1.1 2009-03-20 11:52:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_DESTROYEDEVENT_HH_
#define _TUNNEL_DESTROYEDEVENT_HH_

#include <string>
#include "Event.hh"
#include "IdentifyEvent.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Tunneler;

class TunnelDestroyedEvent : public Event, public IdentifyEvent<TunnelID> {
public:
	// Construction/destruction
	TunnelDestroyedEvent(Tunneler* tunneler, const TunnelID& tid);
	virtual ~TunnelDestroyedEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

protected:

	/********/
	/* Data */
	/********/

	// Tunneler to invoke event for
	Tunneler*						m_tunneler;

	// ID of tunnel shutdown is for
	TunnelID							m_tid;

};


}	// namespace

#endif

