/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Uniquely identify an individual tunneled connection.
 *
 * $Id: TunnelID.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_ID_HH_
#define _TUNNEL_ID_HH_

#include <string>
#include <iostream>
#include "Exceptions.hh"
#include "TunnelerID.hh"
#include "Mutex.hh"

namespace HTTPTunnel {

class ClientSideConfig;

class TunnelID {
public:
	// Construction/destruction
	TunnelID();
	TunnelID(ClientSideConfig* cfg);
	TunnelID(std::string id) throw(InvalidTunnelID, InvalidTunnelerID);
	TunnelID(const TunnelID& that);
	~TunnelID();

	// Assignment
	TunnelID& operator=(const TunnelID& that);

	// Comparison operator
	bool operator==(const TunnelID& that) const;
	// Less than operator for sorting
	bool operator<(const TunnelID& that) const;

	// Accessors
	unsigned int getID(void) const;
	unsigned int getProcID(void) const;
	const TunnelerID& getTunnelerID(void) const;
	Enums::Protocol getProtocol(void) const;

	// Create a representation of ourselves as a string
	std::string toString(void) const;


	/**************/
	/* Predicates */
	/**************/

	// Compare 2 TunnelIDs from pointers
	struct Less {
		bool operator()(const TunnelID* const& id1, const TunnelID* const& id2) {
			return (*id1 < *id2);
		}
	};


private:

	/***********/
	/* Methods */
	/***********/

	// Get next unique ID
	static unsigned int getNextID(void);


	/********/
	/* Data */
	/********/

	// Unique tunnel count ID from creating client process
	unsigned int					m_id;

	// Client tunneler process ID
	unsigned int					m_cliProcID;

	// Tunneler ID
	TunnelerID						m_tunnelerID;

	// A counter for creating unique IDs
	static unsigned int			c_idCount;
	static Mutex					c_idCountMtx;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const TunnelID& tid);


}	// namespace

#endif

