/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various parameters to be used by a Tunnel when tunneling.
 *
 * $Id: TunnelParms.hh,v 1.2 2008-07-25 12:14:54 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_PARMS_HH_
#define _TUNNEL_PARMS_HH_

#include "Tunnel.hh"
#include "Time.hh"

namespace HTTPTunnel {

class TunnelParms {
public:
	// Construction/destruction
	TunnelParms(Tunnel::TunnelTestState testState);
	TunnelParms(const TunnelParms& that);
	virtual ~TunnelParms();

	// Assignment
	TunnelParms& operator=(const TunnelParms& that);

	// Accessors
	virtual unsigned int getMaxPayloadSize(bool useHeader) const = 0;
	const Time& getCreateTime(void) const;
	Tunnel::TunnelTestState getTestState(void) const;
	bool testsCompleted(void) const;

	// Mutators
	void resetTestState(void);


protected:

	/********/
	/* Data */
	/********/

	// Time we were created
	Time								m_createTime;

	// Test state of tunnel when it generated these results
	Tunnel::TunnelTestState		m_testState;

};


}	// namespace

#endif

