/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating a tunnel has changed state.
 *
 * $Id: TunnelStateEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "TunnelStateEvent.hh"
#include "Tunneler.hh"
#include "Debug.hh"
#include "Exceptions.hh"


namespace HTTPTunnel {


// Construction/destruction
TunnelStateEvent::TunnelStateEvent(Tunneler* tunneler, const TunnelID& tid,
	Tunnel::TunnelState state)
: Event(), IdentifyEvent<TunnelID>(tid), m_tunneler(tunneler), m_tid(tid),
  m_state(state)
{
}

TunnelStateEvent::~TunnelStateEvent()
{
}


// Display event details for debugging
void TunnelStateEvent::details(std::stringstream& dbg)
{
	dbg << "TunnelStateEvent: ";
	Event::details(dbg);
}


// Forward the event
void TunnelStateEvent::execute(void)
{
	DPRINTV("TunnelStateEvent::execute()");

	// Let controlling tunneler know
	m_tunneler->tunnelStateChanged(m_tid, m_state);
}


}	// namespace

