/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * An event indicating a tunnel has changed state.
 *
 * $Id: TunnelStateEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_STATE_EVENT_HH_
#define _TUNNEL_STATE_EVENT_HH_

#include "Event.hh"
#include "TunnelID.hh"
#include "Tunnel.hh"
#include "IdentifyEvent.hh"

namespace HTTPTunnel {

class Tunneler;

class TunnelStateEvent : public Event, public IdentifyEvent<TunnelID> {
public:
	// Construction/destruction
	TunnelStateEvent(Tunneler* tunneler, const TunnelID& tid,
		Tunnel::TunnelState state);
	virtual ~TunnelStateEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

protected:

	// Owning tunneler
	Tunneler*							m_tunneler;

	// Tunnel ID
	TunnelID								m_tid;

	// New tunnel state
	Tunnel::TunnelState				m_state;

};


}	// namespace

#endif
