/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various stats relating to a tunnel.
 *
 * $Id: TunnelStats.cc,v 1.2 2008-08-07 20:30:20 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "TunnelStats.hh"


namespace HTTPTunnel {


// Construction/destruction
TunnelStats::TunnelStats(const TunnelID& tid, bool isTest, std::string connState,
	std::string testState, std::string destAddr, unsigned int rawBytesIn,
	unsigned int rawBytesOut, unsigned int httpBytesIn, unsigned int httpBytesOut,
	const User& user, std::vector<std::string>& notifs)
: m_tid(tid), m_isTest(isTest), m_connState(connState), m_testState(testState),
  m_destAddr(destAddr), m_rawBytesIn(rawBytesIn), m_rawBytesOut(rawBytesOut),
  m_httpBytesIn(httpBytesIn), m_httpBytesOut(httpBytesOut), m_user(user),
  m_notifs(notifs)
{
}

TunnelStats::TunnelStats(const TunnelStats& that)
: m_tid(that.m_tid), m_isTest(that.m_isTest), m_connState(that.m_connState),
  m_testState(that.m_testState), m_destAddr(that.m_destAddr), m_rawBytesIn(that.m_rawBytesIn),
  m_rawBytesOut(that.m_rawBytesOut), m_httpBytesIn(that.m_httpBytesIn),
  m_httpBytesOut(that.m_httpBytesOut), m_user(that.m_user), m_notifs(that.m_notifs)
{
}

TunnelStats::~TunnelStats()
{
}


// Assignment
TunnelStats& TunnelStats::operator=(const TunnelStats& that)
{
	// Self assignment
	if(this != &that) {
		m_tid = that.m_tid;
		m_isTest = that.m_isTest;
		m_connState = that.m_connState;
		m_testState = that.m_testState;
		m_destAddr = that.m_destAddr;
		m_rawBytesIn = that.m_rawBytesIn;
		m_rawBytesOut = that.m_rawBytesOut;
		m_httpBytesIn = that.m_httpBytesIn;
		m_httpBytesOut = that.m_httpBytesOut;
		m_user = that.m_user;
		m_notifs = that.m_notifs;
	}

	return *this;
}


/*************/
/* Accessors */
/*************/


// Get ID of tunnel we are for
const TunnelID& TunnelStats::getTID(void) const
{
	return m_tid;
}

// Get whether tunnel is a test tunnel
bool TunnelStats::isTest(void) const
{
	return m_isTest;
}

// Get tunnel connection state
std::string TunnelStats::getConnState(void) const
{
	return m_connState;
}

// Get testing state
std::string TunnelStats::getTestState(void) const
{
	return m_testState;
}

// Get destination address
std::string TunnelStats::getDestAddr(void) const
{
	return m_destAddr;
}

// Get raw byte counts
unsigned int TunnelStats::getRawBytesIn(void) const
{
	return m_rawBytesIn;
}
unsigned int TunnelStats::getRawBytesOut(void) const
{
	return m_rawBytesOut;
}

// Get HTTP byte counts
unsigned int TunnelStats::getHTTPBytesIn(void) const
{
	return m_httpBytesIn;
}
unsigned int TunnelStats::getHTTPBytesOut(void) const
{
	return m_httpBytesOut;
}

// Get user details
const User& TunnelStats::getUser(void) const
{
	return m_user;
}

// Get list of received notification msgs
std::vector<std::string> TunnelStats::getNotifs(void) const
{
	return m_notifs;
}


}	// namespace

