/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Various stats relating to a tunnel.
 *
 * $Id: TunnelStats.hh,v 1.3 2008-08-07 20:30:20 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNEL_STATS_HH_
#define _TUNNEL_STATS_HH_

#include <string>
#include <vector>
#include "TunnelID.hh"
#include "User.hh"

namespace HTTPTunnel {

class TunnelStats {
public:
	// Construction/destruction
	TunnelStats(const TunnelID& tid, bool isTest, std::string connState,
		std::string testState, std::string destAddr, unsigned int rawBytesIn,
		unsigned int rawBytesOut, unsigned int httpBytesIn, unsigned int httpBytesOut,
		const User& user, std::vector<std::string>& notifs);
	TunnelStats(const TunnelStats& that);
	~TunnelStats();

	// Assignment
	TunnelStats& operator=(const TunnelStats& that);

	// Accessors
	const TunnelID& getTID(void) const;
	bool isTest(void) const;
	std::string getConnState(void) const;
	std::string getTestState(void) const;
	std::string getDestAddr(void) const;
	unsigned int getRawBytesIn(void) const;
	unsigned int getRawBytesOut(void) const;
	unsigned int getHTTPBytesIn(void) const;
	unsigned int getHTTPBytesOut(void) const;
	const User& getUser(void) const;
	std::vector<std::string> getNotifs(void) const;


private:

	/********/
	/* Data */
	/********/

	// TunnelID these stats relate to
	TunnelID							m_tid;

	// Is it a test tunnel?
	bool								m_isTest;

	// Connection state
	std::string						m_connState;

	// Testing state
	std::string						m_testState;

	// Tunnel destination address
	std::string						m_destAddr;

	// Data transfer counts
	unsigned int					m_rawBytesIn;
	unsigned int					m_rawBytesOut;
	unsigned int					m_httpBytesIn;
	unsigned int					m_httpBytesOut;

	// User details
	User								m_user;

	// Notifications recvd
	std::vector<std::string>	m_notifs;

};


}	// namespace

#endif

