/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * Uniquely identify an individual tunneler.
 *
 * $Id: TunnelerID.hh,v 1.2 2008-05-15 14:26:22 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TUNNELER_ID_HH_
#define _TUNNELER_ID_HH_

#include <string>
#include <iostream>
#include "Exceptions.hh"
#include "Enums.hh"
#include "Mutex.hh"

namespace HTTPTunnel {

class SideConfig;

class TunnelerID {
public:
	// Construction/destruction
	TunnelerID();
	TunnelerID(SideConfig* cfg);
	TunnelerID(std::string id) throw(InvalidTunnelerID);
	TunnelerID(const TunnelerID& that);
	~TunnelerID();

	// Assignment
	TunnelerID& operator=(const TunnelerID& that);

	// Comparison operator
	bool operator==(const TunnelerID& that) const;
	// Less than operator for sorting
	bool operator<(const TunnelerID& that) const;

	// Accessors
	std::string getClientName(void) const;
	std::string getClientIP(void) const;
	unsigned int getClientPort(void) const;
	Enums::Protocol getProtocol(void) const;

	// Create a representation of ourselves as a string
	std::string toString(void) const;


	/**************/
	/* Predicates */
	/**************/

	// Compare 2 TunnelerIDs from pointers
	struct Less {
		bool operator()(const TunnelerID* const& id1, const TunnelerID* const& id2) {
			return (*id1 < *id2);
		}
	};


private:

	/***********/
	/* Methods */
	/***********/

	// Get next unique ID
	static unsigned int getNextID(void);


	/********/
	/* Data */
	/********/

	// Client host name
	std::string						m_cliName;

	// Client end IP and port
	std::string						m_cliIP;
	unsigned int					m_cliPort;

	// Protocol being tunneled
	Enums::Protocol				m_protocol;

	// A counter for creating unique IDs
	static unsigned int			c_idCount;
	static Mutex					c_idCountMtx;

};


// Output to a stream
std::ostream& operator<<(std::ostream& str, const TunnelerID& tid);


}	// namespace

#endif

