/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Template methods for client and server tunnel controllers.
 *
 * $Id: TunnelerT.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <vector>
#include "MutexVar.hh"

namespace HTTPTunnel {

// Locate a tunnel matching some predicate
template<class P>
Tunnel* Tunneler::getTunFromPred(P pred)
{
	std::vector<Tunnel*>::iterator tit;
	MutexVar mv(m_tunnelsMtx);
	for(tit = m_tunnels.begin(); tit != m_tunnels.end(); ++tit) {
		if(pred(*tit))
			return *tit;
	}

	// Not found
	return 0;
}


// Locate all tunnels matching some predicate
template<class P>
void Tunneler::getAllTunsFromPred(P pred, std::vector<Tunnel*>& res)
{
	std::vector<Tunnel*>::iterator tit;
	MutexVar mv(m_tunnelsMtx);
	for(tit = m_tunnels.begin(); tit != m_tunnels.end(); ++tit) {
		if(pred(*tit)) {
			res.push_back(*tit);
		}
	}
}


}	// namespace

