/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * An event to check whether a UDP tunnel is silent and can
 * be closed.
 *
 * $Id: UDPSilentEvent.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <iostream>
#include "UDPSilentEvent.hh"
#include "Debug.hh"
#include "Tunneler.hh"


namespace HTTPTunnel {


// Construction/destruction
UDPSilentEvent::UDPSilentEvent(Tunneler* tunneler, const TunnelID& tid)
: TimedEvent(Time(SCHEDULE_TIME)), IdentifyEvent<TunnelID>(tid),
  m_tunneler(tunneler), m_tid(tid)
{
}

UDPSilentEvent::~UDPSilentEvent()
{
}


// Display event details for debugging
void UDPSilentEvent::details(std::stringstream& dbg)
{
	dbg << "UDPSilentEvent: ";
	TimedEvent::details(dbg);
}


// Run the event
void UDPSilentEvent::execute(void)
{
	// Let tunneler know
	m_tunneler->checkDatagramTimeout(m_tid);
}


}	// namespace

