/* (C) 2007 Richard Mills / The Linux Academy Ltd.
 *
 * An event to check whether a UDP tunnel is silent and can
 * be closed.
 *
 * $Id: UDPSilentEvent.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _UDP_SILENT_EVENT_HH_
#define _UDP_SILENT_EVENT_HH_

#include "TimedEvent.hh"
#include "IdentifyEvent.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Tunneler;

class UDPSilentEvent : public TimedEvent, public IdentifyEvent<TunnelID> {
public:
	// Construction/destruction
	UDPSilentEvent(Tunneler* tunneler, const TunnelID& tid);
	virtual ~UDPSilentEvent();

	// Display event details for debugging
	virtual void details(std::stringstream& dbg);

	// Run this event
	virtual void execute(void);

protected:

	/*************/
	/* Constants */
	/*************/

	// Frequency to schedule this event (secs)
	static const time_t			SCHEDULE_TIME		= 10;


	/********/
	/* Data */
	/********/

	// Controlling tunneler
	Tunneler*						m_tunneler;

	// Tunnel ID
	TunnelID							m_tid;

};


}	// namespace

#endif

