/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Class to encode/decode an URL.
 *
 * $Id: URLCode.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _URL_CODE_HH_
#define _URL_CODE_HH_

#include <string>
#include <sstream>

namespace HTTPTunnel {

class URLCode {
public:
	// Construction/destruction
	URLCode();
	~URLCode();

	// Encode/Decode an URL
	std::string encode(const std::string& orig) const;
	std::string decode(const std::string& orig) const;

private:

	/***********/
	/* Methods */
	/***********/

	// Is a character unsafe & in need of encoding?
	bool unsafe(char ch) const;

	// Escape/unescape an unsafe character
	void escape(char ch, std::stringstream& str) const;
	void unescape(std::string& esc, std::stringstream& str) const;


	/********/
	/* Data */
	/********/

	// Static lookup tables & strings
	static const char*				c_unsafeChars;
	static const char					c_hexVals[];

};


}	// namespace

#endif

