/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Useful utility functions.
 *
 * $Id: Utils.hh,v 1.3 2009-02-13 18:14:13 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _UTILS_HH_
#define _UTILS_HH_

#include <string>
#include <vector>
#include "RawBuff.hh"
#include "Mutex.hh"
#include "AddrInfo.hh"
#include "Exceptions.hh"


namespace HTTPTunnel {


// Utility methods
class Utils {
public:

	/*************/
	/* Constants */
	/*************/

	// How large does the buffer need to be for getHostByName()
	static const unsigned int			AUX_HOST_BUFF_SIZE	= 1024;


	/***********/
	/* Methods */
	/***********/

	// Split a string into component parts
	static void SplitString(const std::string str, const std::string sep,
		std::vector<std::string>& res);

	// Convert to hex string
	static std::string ToHex(const unsigned char* data, unsigned int len);

	// Extract the value of a parm="value" pair
	static bool getParmValue(const std::vector<std::string>& args,
		const char* parm, std::string& res);

	// UU encode/decode some string
	static std::string UUEncode(const std::string& src);
	static RawBuff UUDecode(const std::string& src);

	// Base64 encode/decode some string
	static std::string Base64Encode(const std::string& src);
	static RawBuff Base64Decode(const std::string& src);

	// Modified base64 encode/decode some string
	static std::string ModBase64Encode(const std::string& src);
	static RawBuff ModBase64Decode(const std::string& src);

	// URL encode/decode some string
	static std::string URLEncode(const std::string& src);
	static std::string URLDecode(const std::string& src);

	// Resolve an IP address
	static std::string resolveIP(std::string addr);
	static int getHostByName(std::string addr, struct hostent* host,
		char* auxBuff, size_t auxBuffLen);
	static AddrInfo getAddrInfo(std::string addr) throw(AddrLookupError);
	static std::string getPeerName(int sockfd);
	static unsigned int getSockPort(int sockfd);

	// DES functions
	static void DESCrypt(const void* input, const void* key, void* output,
		bool encrypt, bool bigendian);
	static void CreateDESKey(const unsigned char* input, unsigned char* key);


private:

	/***********/
	/* Methods */
	/***********/

	// Decode a single base64 byte
	static char base64DecodeChar(char enc);

	// Decode a single modified base64 byte
	static char modBase64DecodeChar(char enc);

	// DES related helpers
	static void oddParity(unsigned char* buff, unsigned int len);


	/********/
	/* Data */
	/********/

	// Mutex
	static Mutex					c_mtx;

	// Base64 encoding/decoding table
	static char						c_base64Table[64];

	// My special format encoding/decoding table
	static char						c_modBase64Table[64];

};


}	// namespace

#endif

