/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Base class for data writers.
 *
 * $Id: Writer.hh,v 1.2 2008-07-25 12:14:54 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _WRITER_HH_
#define _WRITER_HH_

#ifdef DEBUG_LOG_DATA
#include <fstream>
#endif

#include <string>
#include <vector>
#include "Mutex.hh"
#include "Exceptions.hh"
#include "RawBuff.hh"
#include "TunnelID.hh"

namespace HTTPTunnel {

class Connection;
class Tunnel;
class MsgParms;

class Writer {
public:
	// Construction/destruction
	Writer(Connection* conn);
	virtual ~Writer();


	/***********/
	/* Methods */
	/***********/

	// Process and write some message data to our socket
	virtual void write(MsgParms* parms) throw(CommsError);

	// Write some out-of-band data
	void writeOutOfBand(RawBuff& outOfBand) throw(CommsError);

	// Try to flush all buffered data
	bool flush(bool retry) throw(CommsError);

	// Accessors
	virtual bool dataRemaining(void) const;


protected:

	/*************/
	/* Constants */
	/*************/

	// Time (in milliseconds) between flush attempts
	static const unsigned int		FLUSH_TIME		= 200;


	/***********/
	/* Methods */
	/***********/

	// Attempt to process some data to send out
	virtual void processData(MsgParms* parms, RawBuff& out) throw(WriteError) = 0;

	#ifdef DEBUG_LOG_DATA
	// Log some newly written data
	void logData(const RawBuff& data, std::ofstream* file, unsigned int& lineChar);
	#endif


	/********/
	/* Data */
	/********/

	// A mutex
	Mutex									m_mtx;

	// Our controlling connection
	Connection*							m_conn;


private:

	/***********/
	/* Methods */
	/***********/

	// Write processed raw data to our socket
	void rawWrite(void) throw(WriteError);


	/********/
	/* Data */
	/********/

	// Flag to signal whether we are shutting down
	bool									m_closing;

	// A buffer for storing processed data prior to writing
	RawBuff								m_buff;

};


}	// namespace

#endif

