/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate some payload data.
 *
 * $Id: Payload.cc,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "Payload.hh"
#include "Exceptions.hh"


namespace HTTPTunnel {


// Construction/destruction
Payload::Payload()
: m_seqNo(0), m_payload(), m_split(false), m_sent(false)
{
}

Payload::Payload(SeqNo seqNo, const RawBuff& payload, bool split)
	throw(MemoryError)
: m_seqNo(seqNo), m_payload(payload), m_split(split), m_sent(false)
{
}

Payload::Payload(SeqNo seqNo, const RawBuff& payload, unsigned int length,
	bool split) throw(MemoryError)
: m_seqNo(seqNo), m_payload(payload, length), m_split(split), m_sent(false)
{
}

Payload::Payload(const Payload& that) throw(MemoryError)
: m_seqNo(that.m_seqNo), m_payload(that.m_payload), m_split(that.m_split),
  m_sent(that.m_sent)
{
}

Payload::~Payload()
{
}


// Assignment
Payload& Payload::operator=(const Payload& that) throw(MemoryError)
{
	// Self assignment?
	if(this != &that) {
		m_seqNo = that.m_seqNo;
		m_payload = that.m_payload;
		m_split = that.m_split;
		m_sent = that.m_sent;
	}

	return *this;
}


// Less then operator
bool Payload::operator<(const Payload& that) const
{
	// Compare sequence numbers
	return (m_seqNo < that.m_seqNo);
}


/*************/
/* Accessors */
/*************/


// Get sequence number
const SeqNo& Payload::getSeqNo(void) const
{
	return m_seqNo;
}

// Get payload data
const RawBuff& Payload::getPayload(void) const
{
	return m_payload;
}
RawBuff& Payload::getPayloadMutable(void)
{
	return m_payload;
}

// Get payload size (in bytes)
unsigned int Payload::getPayloadSize(void) const
{
	return m_payload.getLength();
}

// Get payload split indicator
bool Payload::getSplit(void) const
{
	return m_split;
}

// Get whether we've been sent
bool Payload::getSent(void) const
{
	return m_sent;
}


/************/
/* Mutators */
/************/


// Set sequence number
void Payload::setSeqNo(SeqNo seqNo)
{
	m_seqNo = seqNo;
}

// Set payload split indicator
void Payload::setSplit(bool split)
{
	m_split = split;
}

// Set whether we've been sent
void Payload::setSent(bool sent)
{
	m_sent = sent;
}


}	// namespace HTTPTunnel

