/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate some payload data.
 *
 * $Id: Payload.hh,v 1.1.1.1 2008-03-28 13:06:25 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _PAYLOAD_HH_
#define _PAYLOAD_HH_

#include "RawBuff.hh"
#include "Exceptions.hh"
#include "SeqNo.hh"


namespace HTTPTunnel {

class Payload {
public:
	// Construction/destruction
	Payload();
	Payload(SeqNo seqNo, const RawBuff& payload, bool split) throw(MemoryError);
	Payload(SeqNo seqNo, const RawBuff& payload, unsigned int length,
		bool split) throw(MemoryError);
	Payload(const Payload& that) throw(MemoryError);
	~Payload();

	// Assignment
	Payload& operator=(const Payload& that) throw(MemoryError);

	// Operators
	bool operator<(const Payload& that) const;


	// Accessors
	const SeqNo& getSeqNo(void) const;
	const RawBuff& getPayload(void) const;
	RawBuff& getPayloadMutable(void);
	unsigned int getPayloadSize(void) const;
	bool getSplit(void) const;
	bool getSent(void) const;

	// Mutators
	void setSeqNo(SeqNo seqNo);
	void setSplit(bool split);
	void setSent(bool sent);


private:

	// Our sequence number within a tunnel
	SeqNo									m_seqNo;

	// The actual payload data
	RawBuff								m_payload;

	// Split payload indicator
	bool									m_split;

	// Have we been sent?
	bool									m_sent;

};


}	// namespace HTTPTunnel

#endif

